@@ -1,6 +1,7 @@
 """
 napari command line viewer.
 """
+
 import argparse
 import contextlib
 import logging
@@ -12,8 +13,9 @@ from ast import literal_eval
 from itertools import chain, repeat
 from pathlib import Path
 from textwrap import wrap
-from typing import Any, Dict, List
+from typing import Any
 
+from napari.errors import ReaderPluginError
 from napari.utils.translations import trans
 
 
@@ -25,9 +27,9 @@ class InfoAction(argparse.Action):
         from napari.utils import sys_info
 
         logging.basicConfig(level=logging.WARNING)
-        print(sys_info())
-        print("Plugins:")
-        cli.list(fields="", sort="0", format="compact")
+        print(sys_info())  # noqa: T201
+        print('Plugins:')  # noqa: T201
+        cli.list(fields='', sort='0', format='compact')
         sys.exit()
 
 
@@ -38,9 +40,9 @@ class PluginInfoAction(argparse.Action):
         from npe2 import cli
 
         cli.list(
-            fields="name,version,npe2,contributions",
-            sort="name",
-            format="table",
+            fields='name,version,npe2,contributions',
+            sort='name',
+            format='table',
         )
         sys.exit()
 
@@ -51,11 +53,11 @@ class CitationAction(argparse.Action):
         from napari.utils import citation_text
 
         logging.basicConfig(level=logging.WARNING)
-        print(citation_text)
+        print(citation_text)  # noqa: T201
         sys.exit()
 
 
-def validate_unknown_args(unknown: List[str]) -> Dict[str, Any]:
+def validate_unknown_args(unknown: list[str]) -> dict[str, Any]:
     """Convert a list of strings into a dict of valid kwargs for add_* methods.
 
     Will exit program if any of the arguments are unrecognized, or are
@@ -75,23 +77,23 @@ def validate_unknown_args(unknown: List[str]) -> Dict[str, Any]:
 
     from napari.components.viewer_model import valid_add_kwargs
 
-    out: Dict[str, Any] = {}
+    out: dict[str, Any] = {}
     valid = set.union(*valid_add_kwargs().values())
     for i, raw_arg in enumerate(unknown):
-        if not raw_arg.startswith("--"):
+        if not raw_arg.startswith('--'):
             continue
         arg = raw_arg.lstrip('-')
 
-        key, *value = arg.split("=", maxsplit=1)
+        key, *values = arg.split('=', maxsplit=1)
         key = key.replace('-', '_')
         if key not in valid:
-            sys.exit(f"error: unrecognized argument: {raw_arg}")
+            sys.exit(f'error: unrecognized argument: {raw_arg}')
 
-        if value:
-            value = value[0]
+        if values:
+            value = values[0]
         else:
-            if len(unknown) <= i + 1 or unknown[i + 1].startswith("--"):
-                sys.exit(f"error: argument {raw_arg} expected one argument")
+            if len(unknown) <= i + 1 or unknown[i + 1].startswith('--'):
+                sys.exit(f'error: argument {raw_arg} expected one argument')
             value = unknown[i + 1]
         with contextlib.suppress(Exception):
             value = literal_eval(value)
@@ -108,16 +110,16 @@ def parse_sys_argv():
 
     kwarg_options = []
     for layer_type, keys in valid_add_kwargs().items():
-        kwarg_options.append(f"  {layer_type.title()}:")
+        kwarg_options.append(f'  {layer_type.title()}:')
         keys = {k.replace('_', '-') for k in keys}
-        lines = wrap(", ".join(sorted(keys)), break_on_hyphens=False)
-        kwarg_options.extend([f"    {line}" for line in lines])
+        lines = wrap(', '.join(sorted(keys)), break_on_hyphens=False)
+        kwarg_options.extend([f'    {line}' for line in lines])
 
     parser = argparse.ArgumentParser(
         usage=__doc__,
         formatter_class=argparse.RawDescriptionHelpFormatter,
         epilog="optional layer-type-specific arguments (precede with '--'):\n"
-        + "\n".join(kwarg_options),
+        + '\n'.join(kwarg_options),
     )
     parser.add_argument('paths', nargs='*', help='path(s) to view.')
     parser.add_argument(
@@ -125,7 +127,7 @@ def parse_sys_argv():
         '--verbose',
         action='count',
         default=0,
-        help="increase output verbosity",
+        help='increase output verbosity',
     )
     parser.add_argument(
         '-w',
@@ -136,10 +138,10 @@ def parse_sys_argv():
         default=[],
         metavar=('PLUGIN_NAME', 'WIDGET_NAME'),
         help=(
-            "open napari with dock widget from specified plugin name."
-            "(If plugin provides multiple dock widgets, widget name must also "
-            "be provided). Use __all__ to open all dock widgets of a "
-            "specified plugin. Multiple widgets are opened in tabs."
+            'open napari with dock widget from specified plugin name.'
+            '(If plugin provides multiple dock widgets, widget name must also '
+            'be provided). Use __all__ to open all dock widgets of a '
+            'specified plugin. Multiple widgets are opened in tabs.'
         ),
     )
     parser.add_argument(
@@ -180,7 +182,7 @@ def parse_sys_argv():
     )
     parser.add_argument(
         '--layer-type',
-        metavar="TYPE",
+        metavar='TYPE',
         choices=set(layers.NAMES),
         help=(
             'force file to be interpreted as a specific layer type. '
@@ -202,14 +204,14 @@ def parse_sys_argv():
     # this is a hack to allow using "=" as a key=value separator while also
     # allowing nargs='*' on the "paths" argument...
     for idx, item in enumerate(reversed(args.paths)):
-        if item.startswith("--"):
+        if item.startswith('--'):
             unknown.append(args.paths.pop(len(args.paths) - idx - 1))
     kwargs = validate_unknown_args(unknown) if unknown else {}
 
     return args, kwargs
 
 
-def _run():
+def _run() -> None:
     from napari import Viewer, run
     from napari.settings import get_settings
 
@@ -221,7 +223,7 @@ def _run():
     level = levels[min(2, args.verbose)]  # prevent index error
     logging.basicConfig(
         level=level,
-        format="%(asctime)s %(levelname)s %(message)s",
+        format='%(asctime)s : %(levelname)s : %(threadName)s : %(message)s',
         datefmt='%H:%M:%S',
     )
 
@@ -232,14 +234,14 @@ def _run():
             settings = get_settings()
         settings.reset()
         settings.save()
-        sys.exit("Resetting settings to default values.\n")
+        sys.exit('Resetting settings to default values.\n')
 
     if args.plugin:
         # make sure plugin is only used when files are specified
         if not args.paths:
             sys.exit(
                 "error: The '--plugin' argument is only valid "
-                "when providing a file name"
+                'when providing a file name'
             )
         # I *think* that Qt is looking in sys.argv for a flag `--plugins`,
         # which emits "WARNING: No such plugin for spec 'builtins'"
@@ -280,25 +282,30 @@ def _run():
             npe2_plugins = []
             for plugin in args.with_:
                 pname, *wnames = plugin
-                for _name, (_pname, _wnames) in _npe2.widget_iterator():
-                    if _name == 'dock' and pname == _pname:
+                for name, (w_pname, wnames) in _npe2.widget_iterator():
+                    if name == 'dock' and pname == w_pname:
                         npe2_plugins.append(plugin)
                         if '__all__' in wnames:
-                            wnames = _wnames
+                            wnames = wnames
                         break
 
-                for _name, (_pname, _wnames) in plugin_manager.iter_widgets():
-                    if _name == 'dock' and pname == _pname:
+                for name2, (
+                    w_pname,
+                    wnames_dict,
+                ) in plugin_manager.iter_widgets():
+                    if name2 == 'dock' and pname == w_pname:
                         plugin_manager_plugins.append(plugin)
                         if '__all__' in wnames:
                             # Plugin_manager iter_widgets return wnames as dict keys
-                            wnames = list(_wnames.keys())
-                        print(
+                            wnames = list(wnames_dict)
+                        warnings.warn(
                             trans._(
                                 'Non-npe2 plugin {pname} detected. Disable tabify for this plugin.',
                                 deferred=True,
                                 pname=pname,
-                            )
+                            ),
+                            RuntimeWarning,
+                            stacklevel=3,
                         )
                         break
 
@@ -337,13 +344,20 @@ def _run():
                 stacklevel=3,
             )
             args.stack = True
-        viewer._window._qt_viewer._qt_open(
-            args.paths,
-            stack=args.stack,
-            plugin=args.plugin,
-            layer_type=args.layer_type,
-            **kwargs,
-        )
+        try:
+            viewer._window._qt_viewer._qt_open(
+                args.paths,
+                stack=args.stack,
+                plugin=args.plugin,
+                layer_type=args.layer_type,
+                **kwargs,
+            )
+        except ReaderPluginError:
+            logging.exception(
+                'Loading %s with %s failed with errors',
+                args.paths,
+                args.plugin,
+            )
 
         if args.with_:
             # Non-npe2 plugins disappear on tabify or if tabified npe2 plugins are loaded after them.
@@ -354,15 +368,15 @@ def _run():
             ):
                 pname, *wnames = plugin
                 if '__all__' in wnames:
-                    for name, (_pname, _wnames) in chain(
+                    for name, (_pname, wnames_collection) in chain(
                         _npe2.widget_iterator(), plugin_manager.iter_widgets()
                     ):
                         if name == 'dock' and pname == _pname:
-                            if isinstance(_wnames, dict):
+                            if isinstance(wnames_collection, dict):
                                 # Plugin_manager iter_widgets return wnames as dict keys
-                                wnames = list(_wnames.keys())
+                                wnames = list(wnames_collection.keys())
                             else:
-                                wnames = _wnames
+                                wnames = wnames_collection
                             break
 
                 if wnames:
@@ -435,14 +449,22 @@ def _maybe_rerun_with_macos_fixes():
        This requires relaunching the app from a symlink to the
        desired python executable, conveniently named 'napari'.
     """
-    if sys.platform != "darwin":
+    from napari._qt import API_NAME
+
+    # This import mus be here to raise exception about PySide6 problem
+
+    if (
+        sys.platform != 'darwin'
+        or 'pdb' in sys.modules
+        or 'pydevd' in sys.modules
+    ):
         return
 
-    if "_NAPARI_RERUN_WITH_FIXES" in os.environ:
+    if '_NAPARI_RERUN_WITH_FIXES' in os.environ:
         # This function already ran, do not recurse!
         # We also restore sys.executable to its initial value,
         # if we used a symlink
-        if exe := os.environ.pop("_NAPARI_SYMLINKED_EXECUTABLE", ""):
+        if exe := os.environ.pop('_NAPARI_SYMLINKED_EXECUTABLE', ''):
             sys.executable = exe
         return
 
@@ -450,16 +472,14 @@ def _maybe_rerun_with_macos_fixes():
     import subprocess
     from tempfile import mkdtemp
 
-    from qtpy import API_NAME
-
     # In principle, we will relaunch to the same python we were using
     executable = sys.executable
     cwd = Path.cwd()
 
     _MACOS_AT_LEAST_CATALINA = int(platform.release().split('.')[0]) >= 19
     _MACOS_AT_LEAST_BIG_SUR = int(platform.release().split('.')[0]) >= 20
-    _RUNNING_CONDA = "CONDA_PREFIX" in os.environ
-    _RUNNING_PYTHONW = "PYTHONEXECUTABLE" in os.environ
+    _RUNNING_CONDA = 'CONDA_PREFIX' in os.environ
+    _RUNNING_PYTHONW = 'PYTHONEXECUTABLE' in os.environ
 
     # 1) quick fix for Big Sur py3.9 and qt 5
     # https://github.com/napari/napari/pull/1894
@@ -505,35 +525,35 @@ def _maybe_rerun_with_macos_fixes():
         # When napari is launched from the conda bundle shortcut
         # it already has the right 'napari' name in the app title
         # and __CFBundleIdentifier is set to 'com.napari._(<version>)'
-        "napari" not in os.environ.get("__CFBUNDLEIDENTIFIER", "")
+        'napari' not in os.environ.get('__CFBUNDLEIDENTIFIER', '')
         # with a sys.executable named napari,
         # macOS should have picked the right name already
-        or os.path.basename(executable) != "napari"
+        or os.path.basename(executable) != 'napari'
     )
     if _NEEDS_SYMLINK:
-        tempdir = mkdtemp(prefix="symlink-to-fix-macos-menu-name-")
+        tempdir = mkdtemp(prefix='symlink-to-fix-macos-menu-name-')
         # By using a symlink with basename napari
         # we make macOS take 'napari' as the program name
-        napari_link = os.path.join(tempdir, "napari")
+        napari_link = os.path.join(tempdir, 'napari')
         os.symlink(executable, napari_link)
         # Pass original executable to the subprocess so it can restore it later
-        env["_NAPARI_SYMLINKED_EXECUTABLE"] = executable
+        env['_NAPARI_SYMLINKED_EXECUTABLE'] = executable
         executable = napari_link
 
     # if at this point 'executable' is different from 'sys.executable', we
     # need to launch the subprocess to apply the fixes
     if sys.executable != executable:
-        env["_NAPARI_RERUN_WITH_FIXES"] = "1"
-        if Path(sys.argv[0]).name == "napari":
+        env['_NAPARI_RERUN_WITH_FIXES'] = '1'
+        if Path(sys.argv[0]).name == 'napari':
             # launched through entry point, we do that again to avoid
             # issues with working directory getting into sys.path (#5007)
             cmd = [executable, sys.argv[0]]
         else:  # we assume it must have been launched via '-m' syntax
-            cmd = [executable, "-m", "napari"]
+            cmd = [executable, '-m', 'napari']
 
         # this fixes issues running from a venv/virtualenv based virtual
         # environment with certain python distributions (e.g. pyenv, asdf)
-        env["PYTHONEXECUTABLE"] = sys.executable
+        env['PYTHONEXECUTABLE'] = sys.executable
 
         # Append original command line arguments.
         if len(sys.argv) > 1:
@@ -556,7 +576,7 @@ def main():
     # Prevent https://github.com/napari/napari/issues/3415
     # This one fix is needed _after_ a potential relaunch,
     # that's why it's here and not in _maybe_rerun_with_macos_fixes()
-    if sys.platform == "darwin":
+    if sys.platform == 'darwin':
         import multiprocessing
 
         multiprocessing.set_start_method('fork')
