@@ -33,28 +33,30 @@ General rendering flow:
    https://doc.qt.io/qt-5/stylesheet-reference.html#list-of-sub-controls
 
 """
+
 from __future__ import annotations
 
-from functools import partial
 from typing import TYPE_CHECKING
+from weakref import WeakKeyDictionary, ref
 
-from qtpy.QtCore import QPoint, QSize, Qt, QTimer
-from qtpy.QtGui import QPixmap
+from qtpy.QtCore import QPoint, QSize, Qt, Signal
+from qtpy.QtGui import QMouseEvent, QMovie, QPixmap
 from qtpy.QtWidgets import QStyledItemDelegate
 
-from ...layers._layer_actions import _LAYER_ACTIONS
-from ...utils.context import get_context
-from ..qt_resources import QColoredSVGIcon
-from ..widgets.qt_action_context_menu import QtActionContextMenu
-from ._base_item_model import ItemRole
-from .qt_layer_model import ThumbnailRole
+from napari._app_model.constants import MenuId
+from napari._app_model.context import get_context
+from napari._qt._qapp_model import build_qmodel_menu
+from napari._qt.containers._base_item_model import ItemRole
+from napari._qt.containers.qt_layer_model import LoadedRole, ThumbnailRole
+from napari._qt.qt_resources import QColoredSVGIcon
+from napari.resources import LOADING_GIF_PATH
 
 if TYPE_CHECKING:
     from qtpy import QtCore
     from qtpy.QtGui import QPainter
     from qtpy.QtWidgets import QStyleOptionViewItem, QWidget
 
-    from ...components.layerlist import LayerList
+    from napari.components.layerlist import LayerList
 
 
 class LayerDelegate(QStyledItemDelegate):
@@ -74,6 +76,16 @@ class LayerDelegate(QStyledItemDelegate):
     the appropriate icon for the layer, and some additional style/UX issues.
     """
 
+    loading_frame_changed = Signal()
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self._load_movie = QMovie(LOADING_GIF_PATH)
+        self._load_movie.setScaledSize(QSize(18, 18))
+        self._load_movie.frameChanged.connect(self.loading_frame_changed)
+        self._layer_visibility_states = WeakKeyDictionary()
+        self._alt_click_layer = lambda: None
+
     def paint(
         self,
         painter: QPainter,
@@ -86,10 +98,14 @@ class LayerDelegate(QStyledItemDelegate):
         self.get_layer_icon(option, index)
         # paint the standard itemView (includes name, icon, and vis. checkbox)
         super().paint(painter, option, index)
+        # paint loading indicator if needed
+        self._paint_loading(painter, option, index)
         # paint the thumbnail
         self._paint_thumbnail(painter, option, index)
 
-    def get_layer_icon(self, option, index):
+    def get_layer_icon(
+        self, option: QStyleOptionViewItem, index: QtCore.QModelIndex
+    ):
         """Add the appropriate QIcon to the item based on the layer type."""
         layer = index.data(ItemRole)
         if layer is None:
@@ -105,23 +121,52 @@ class LayerDelegate(QStyledItemDelegate):
         except ValueError:
             return
         # guessing theme rather than passing it through.
-        bg = option.palette.color(option.palette.Background).red()
+        bg = option.palette.color(option.palette.ColorRole.Window).red()
         option.icon = icon.colored(theme='dark' if bg < 128 else 'light')
         option.decorationSize = QSize(18, 18)
-        option.decorationPosition = option.Right  # put icon on the right
-        option.features |= option.HasDecoration
+        option.decorationPosition = (
+            option.Position.Right
+        )  # put icon on the right
+        option.features |= option.ViewItemFeature.HasDecoration
+
+    def _paint_loading(
+        self,
+        painter: QPainter,
+        option: QStyleOptionViewItem,
+        index: QtCore.QModelIndex,
+    ):
+        """Paint loading layer indicator."""
+        loaded = index.data(LoadedRole)
+        if not loaded:
+            self._load_movie.start()
+            load_rect = option.rect.translated(4, 8)
+            h = index.data(Qt.ItemDataRole.SizeHintRole).height() - 16
+            load_rect.setWidth(h)
+            load_rect.setHeight(h)
+            painter.drawPixmap(load_rect, self._load_movie.currentPixmap())
 
     def _paint_thumbnail(self, painter, option, index):
         """paint the layer thumbnail."""
         # paint the thumbnail
         # MAGICNUMBER: numbers from the margin applied in the stylesheet to
         # QtLayerTreeView::item
-        thumb_rect = option.rect.translated(-2, 2)
-        h = index.data(Qt.SizeHintRole).height() - 4
-        thumb_rect.setWidth(h)
-        thumb_rect.setHeight(h)
-        image = index.data(ThumbnailRole)
-        painter.drawPixmap(thumb_rect, QPixmap.fromImage(image))
+        loaded = index.data(LoadedRole)
+        if loaded:
+            # only pause the loading movie if all the layers are loaded. The
+            # last layer that enters the loaded state will pause the load
+            # movie. This is needed since there is only one instance of the
+            # delegate and therefore only one instance of the load movie shared
+            # between all the layer items.
+            all_loaded = index.model().sourceModel().all_loaded()
+            if all_loaded:
+                self._load_movie.setPaused(True)
+
+            thumb_rect = option.rect.translated(-2, 2)
+            h = index.data(Qt.ItemDataRole.SizeHintRole).height() - 4
+            thumb_rect.setWidth(h)
+            thumb_rect.setHeight(h)
+            image = index.data(ThumbnailRole)
+            painter.drawPixmap(thumb_rect, QPixmap.fromImage(image))
 
     def createEditor(
         self,
@@ -134,7 +179,9 @@ class LayerDelegate(QStyledItemDelegate):
         self.get_layer_icon(option, index)
         editor = super().createEditor(parent, option, index)
         # make sure editor has same alignment as the display name
-        editor.setAlignment(Qt.Alignment(index.data(Qt.TextAlignmentRole)))
+        editor.setAlignment(
+            Qt.AlignmentFlag(index.data(Qt.ItemDataRole.TextAlignmentRole))
+        )
         return editor
 
     def editorEvent(
@@ -149,45 +196,124 @@ class LayerDelegate(QStyledItemDelegate):
         This can be used to customize how the delegate handles mouse/key events
         """
         if (
-            event.type() == event.MouseButtonRelease
-            and event.button() == Qt.RightButton
+            event.type() == QMouseEvent.MouseButtonRelease
+            and event.button() == Qt.MouseButton.RightButton
         ):
-            self.show_context_menu(
-                index, model, event.globalPos(), option.widget
+            pnt = (
+                event.globalPosition().toPoint()
+                if hasattr(event, 'globalPosition')
+                else event.globalPos()
             )
 
+            self.show_context_menu(index, model, pnt, option.widget)
+
         # if the user clicks quickly on the visibility checkbox, we *don't*
         # want it to be interpreted as a double-click.  We want the visibilty
         # to simply be toggled.
-        if event.type() == event.MouseButtonDblClick:
+        if event.type() == QMouseEvent.MouseButtonDblClick:
             self.initStyleOption(option, index)
             style = option.widget.style()
             check_rect = style.subElementRect(
-                style.SE_ItemViewItemCheckIndicator, option, option.widget
+                style.SubElement.SE_ItemViewItemCheckIndicator,
+                option,
+                option.widget,
             )
             if check_rect.contains(event.pos()):
-                cur_state = index.data(Qt.CheckStateRole)
-                if model.flags(index) & Qt.ItemIsUserTristate:
+                cur_state = index.data(Qt.ItemDataRole.CheckStateRole)
+                if model.flags(index) & Qt.ItemFlag.ItemIsUserTristate:
                     state = Qt.CheckState((cur_state + 1) % 3)
                 else:
-                    state = Qt.Unchecked if cur_state else Qt.Checked
-                return model.setData(index, state, Qt.CheckStateRole)
+                    state = (
+                        Qt.CheckState.Unchecked
+                        if cur_state
+                        else Qt.CheckState.Checked
+                    )
+                return model.setData(
+                    index, state, Qt.ItemDataRole.CheckStateRole
+                )
+
+        # catch alt-click on the vis checkbox and hide *other* layer visibility
+        # on second alt-click, restore the visibility state of the layers
+        if event.type() == QMouseEvent.MouseButtonRelease and (
+            event.button() == Qt.MouseButton.LeftButton
+            and event.modifiers() == Qt.AltModifier
+        ):
+            self.initStyleOption(option, index)
+            style = option.widget.style()
+            check_rect = style.subElementRect(
+                style.SubElement.SE_ItemViewItemCheckIndicator,
+                option,
+                option.widget,
+            )
+            if check_rect.contains(event.pos()):
+                return self._show_on_alt_click_hide_others(model, index)
+
+        # on regular click of visibility icon, clear alt-click state
+        if event.type() == QMouseEvent.MouseButtonRelease and (
+            event.button() == Qt.MouseButton.LeftButton
+        ):
+            self.initStyleOption(option, index)
+            style = option.widget.style()
+            check_rect = style.subElementRect(
+                style.SubElement.SE_ItemViewItemCheckIndicator,
+                option,
+                option.widget,
+            )
+            if check_rect.contains(event.pos()):
+                self._alt_click_layer = lambda: None
+
         # refer all other events to the QStyledItemDelegate
         return super().editorEvent(event, model, option, index)
 
+    def _show_on_alt_click_hide_others(
+        self,
+        model: QtCore.QAbstractItemModel,
+        index: QtCore.QModelIndex,
+    ) -> QtCore.QAbstractItemModel:
+        """On alt/option click of a layer show the layer, hide other layers,
+        to be restored once a layer is alt/option-clicked a second time.
+        """
+        alt_clicked_layer = index.data(ItemRole)
+        layer_list: LayerList = model.sourceModel()._root
+        # show the alt-clicked layer
+        state = Qt.CheckState.Checked
+        if self._alt_click_layer() is None:
+            # first click on visibility, so store visibility & hide others
+            for layer in layer_list:
+                self._layer_visibility_states[layer] = layer.visible
+                layer.visible = layer == alt_clicked_layer  # hide others
+            # make a note that this layer was alt-clicked
+            self._alt_click_layer = ref(alt_clicked_layer)
+        elif self._alt_click_layer() is alt_clicked_layer:
+            # second alt-click on same layer, so restore visibility
+            # account for any added/deleted layers when restoring
+            for layer in layer_list:
+                if layer in self._layer_visibility_states:
+                    layer.visible = self._layer_visibility_states[layer]
+            # restore clicked layer to original state
+            if not alt_clicked_layer.visible:
+                state = Qt.CheckState.Unchecked
+            # reset alt-click state
+            self._alt_click_layer = lambda: None
+        else:
+            # option-click on a different layer, hide others, show it
+            for layer in layer_list:
+                layer.visible = layer is alt_clicked_layer
+            # make a note that this layer was alt-clicked
+            self._alt_click_layer = ref(alt_clicked_layer)
+
+        return model.setData(index, state, Qt.ItemDataRole.CheckStateRole)
+
     def show_context_menu(self, index, model, pos: QPoint, parent):
         """Show the layerlist context menu.
-
         To add a new item to the menu, update the _LAYER_ACTIONS dict.
         """
         if not hasattr(self, '_context_menu'):
-            self._context_menu = QtActionContextMenu(_LAYER_ACTIONS)
+            self._context_menu = build_qmodel_menu(
+                MenuId.LAYERLIST_CONTEXT, parent=parent
+            )
 
         layer_list: LayerList = model.sourceModel()._root
-        self._context_menu.update_from_context(get_context(layer_list))
-        action = self._context_menu.exec_(pos)
-        if action is not None and isinstance(action.data(), dict):
-            # action.data will be a callable that accepts a layer_list instance
-            action = action.data().get('action')
-            if action:
-                QTimer.singleShot(0, partial(action, layer_list))
+        ctx = get_context(layer_list)
+        self._context_menu.update_from_context(ctx)
+        self._context_menu.exec_(pos)
