@@ -4,23 +4,22 @@ import re
 import signal
 import socket
 import weakref
+from collections.abc import Iterable, Sequence
 from contextlib import contextmanager
-from functools import lru_cache, partial
-from typing import Iterable, Sequence, Union
+from functools import partial
+from typing import Union
 
 import numpy as np
 import qtpy
 from qtpy.QtCore import (
     QByteArray,
     QCoreApplication,
-    QPoint,
     QPropertyAnimation,
-    QSize,
     QSocketNotifier,
     Qt,
     QThread,
 )
-from qtpy.QtGui import QColor, QCursor, QDrag, QImage, QPainter, QPen, QPixmap
+from qtpy.QtGui import QColor, QCursor, QDrag, QImage, QPainter, QPixmap
 from qtpy.QtWidgets import (
     QGraphicsColorizeEffect,
     QGraphicsOpacityEffect,
@@ -35,8 +34,8 @@ from napari.utils.events.custom_types import Array
 from napari.utils.misc import is_sequence
 from napari.utils.translations import trans
 
-QBYTE_FLAG = "!QBYTE_"
-RICH_TEXT_PATTERN = re.compile("<[^\n]+>")
+QBYTE_FLAG = '!QBYTE_'
+RICH_TEXT_PATTERN = re.compile('<[^\n]+>')
 
 
 def is_qbyte(string: str) -> bool:
@@ -159,108 +158,6 @@ def set_widgets_enabled_with_opacity(
         widget.setGraphicsEffect(op)
 
 
-@lru_cache(maxsize=64)
-def square_pixmap(size):
-    """Create a white/black hollow square pixmap. For use as labels cursor."""
-    size = max(int(size), 1)
-    pixmap = QPixmap(QSize(size, size))
-    pixmap.fill(Qt.GlobalColor.transparent)
-    painter = QPainter(pixmap)
-    painter.setPen(Qt.GlobalColor.white)
-    painter.drawRect(0, 0, size - 1, size - 1)
-    painter.setPen(Qt.GlobalColor.black)
-    painter.drawRect(1, 1, size - 3, size - 3)
-    painter.end()
-    return pixmap
-
-
-@lru_cache(maxsize=64)
-def crosshair_pixmap():
-    """Create a cross cursor with white/black hollow square pixmap in the middle.
-    For use as points cursor."""
-
-    size = 25
-
-    pixmap = QPixmap(QSize(size, size))
-    pixmap.fill(Qt.GlobalColor.transparent)
-    painter = QPainter(pixmap)
-
-    # Base measures
-    width = 1
-    center = 3  # Must be odd!
-    rect_size = center + 2 * width
-    square = rect_size + width * 4
-
-    pen = QPen(Qt.GlobalColor.white, 1)
-    pen.setJoinStyle(Qt.PenJoinStyle.MiterJoin)
-    painter.setPen(pen)
-
-    # # Horizontal rectangle
-    painter.drawRect(0, (size - rect_size) // 2, size - 1, rect_size - 1)
-
-    # Vertical rectangle
-    painter.drawRect((size - rect_size) // 2, 0, rect_size - 1, size - 1)
-
-    # Square
-    painter.drawRect(
-        (size - square) // 2, (size - square) // 2, square - 1, square - 1
-    )
-
-    pen = QPen(Qt.GlobalColor.black, 2)
-    pen.setJoinStyle(Qt.PenJoinStyle.MiterJoin)
-    painter.setPen(pen)
-
-    # # Square
-    painter.drawRect(
-        (size - square) // 2 + 2,
-        (size - square) // 2 + 2,
-        square - 4,
-        square - 4,
-    )
-
-    pen = QPen(Qt.GlobalColor.black, 3)
-    pen.setJoinStyle(Qt.PenJoinStyle.MiterJoin)
-    painter.setPen(pen)
-
-    # # # Horizontal lines
-    mid_vpoint = QPoint(2, size // 2)
-    painter.drawLine(
-        mid_vpoint, QPoint(((size - center) // 2) - center + 1, size // 2)
-    )
-    mid_vpoint = QPoint(size - 3, size // 2)
-    painter.drawLine(
-        mid_vpoint, QPoint(((size - center) // 2) + center + 1, size // 2)
-    )
-
-    # # # Vertical lines
-    mid_hpoint = QPoint(size // 2, 2)
-    painter.drawLine(
-        QPoint(size // 2, ((size - center) // 2) - center + 1), mid_hpoint
-    )
-    mid_hpoint = QPoint(size // 2, size - 3)
-    painter.drawLine(
-        QPoint(size // 2, ((size - center) // 2) + center + 1), mid_hpoint
-    )
-
-    painter.end()
-    return pixmap
-
-
-@lru_cache(maxsize=64)
-def circle_pixmap(size: int):
-    """Create a white/black hollow circle pixmap. For use as labels cursor."""
-    size = max(size, 1)
-    pixmap = QPixmap(QSize(size, size))
-    pixmap.fill(Qt.GlobalColor.transparent)
-    painter = QPainter(pixmap)
-    painter.setPen(Qt.GlobalColor.white)
-    painter.drawEllipse(0, 0, size - 1, size - 1)
-    painter.setPen(Qt.GlobalColor.black)
-    painter.drawEllipse(1, 1, size - 3, size - 3)
-    painter.end()
-    return pixmap
-
-
 def drag_with_pixmap(list_widget: QListWidget) -> QDrag:
     """Create a QDrag object with a pixmap of the currently select list item.
 
@@ -365,12 +262,12 @@ def add_flash_animation(
         Color of the flash animation. By default, we use light gray.
     """
     color = transform_color(color)[0]
-    color = (255 * color).astype("int")
+    color = (255 * color).astype('int')
 
     effect = QGraphicsColorizeEffect(widget)
     widget.setGraphicsEffect(effect)
 
-    widget._flash_animation = QPropertyAnimation(effect, b"color")
+    widget._flash_animation = QPropertyAnimation(effect, b'color')
     widget._flash_animation.setStartValue(QColor(0, 0, 0, 0))
     widget._flash_animation.setEndValue(QColor(0, 0, 0, 0))
     widget._flash_animation.setLoopCount(1)
@@ -479,7 +376,7 @@ def qt_might_be_rich_text(text) -> bool:
         return bool(RICH_TEXT_PATTERN.search(text))
 
 
-def in_qt_main_thread():
+def in_qt_main_thread() -> bool:
     """
     Check if we are in the thread in which QApplication object was created.
 
