@@ -116,14 +116,14 @@ vec4 calculateShadedCategoricalColor(vec4 betterColor, vec3 loc, vec3 step)
 """
 
 ISO_CATEGORICAL_SNIPPETS = {
-    "before_loop": """
+    'before_loop': """
         vec4 color3 = vec4(0.0);  // final color
         vec3 dstep = 1.5 / u_shape;  // step to sample derivative, set to match iso shader
         gl_FragColor = vec4(0.0);
         bool discard_fragment = true;
         vec4 label_id = vec4(0.0);
         """,
-    "in_loop": """
+    'in_loop': """
         // check if value is different from the background value
         if ( floatNotEqual(val, categorical_bg_value) ) {
             // Take the last interval in smaller steps
@@ -149,20 +149,20 @@ ISO_CATEGORICAL_SNIPPETS = {
             }
         }
         """,
-    "after_loop": """
+    'after_loop': """
         if (discard_fragment)
             discard;
         """,
 }
 
 TRANSLUCENT_CATEGORICAL_SNIPPETS = {
-    "before_loop": """
+    'before_loop': """
         vec4 color3 = vec4(0.0);  // final color
         gl_FragColor = vec4(0.0);
         bool discard_fragment = true;
         vec4 label_id = vec4(0.0);
         """,
-    "in_loop": """
+    'in_loop': """
         // check if value is different from the background value
         if ( floatNotEqual(val, categorical_bg_value) ) {
             // Take the last interval in smaller steps
@@ -187,7 +187,7 @@ TRANSLUCENT_CATEGORICAL_SNIPPETS = {
             }
         }
         """,
-    "after_loop": """
+    'after_loop': """
         if (discard_fragment)
             discard;
         """,
