@@ -2,7 +2,7 @@
 
 Notes for using the plugin-related fixtures here:
 
-1. The `_mock_npe2_pm` fixture is always used, and it mocks the global npe2 plugin
+1. The `npe2pm_` fixture is always used, and it mocks the global npe2 plugin
    manager instance with a discovery-deficient plugin manager.  No plugins should be
    discovered in tests without explicit registration.
 2. wherever the builtins need to be tested, the `builtins` fixture should be explicitly
@@ -37,49 +37,41 @@ from concurrent.futures import ThreadPoolExecutor
 from contextlib import suppress
 from itertools import chain
 from multiprocessing.pool import ThreadPool
-from typing import TYPE_CHECKING
-from unittest.mock import patch
+from pathlib import Path
+from typing import TYPE_CHECKING, Optional
 from weakref import WeakKeyDictionary
 
+from npe2 import PackageMetadata
+
 with suppress(ModuleNotFoundError):
     __import__('dotenv').load_dotenv()
 
+from datetime import timedelta
+from time import perf_counter
+
 import dask.threaded
 import numpy as np
 import pytest
+from _pytest.pathlib import bestrelpath
 from IPython.core.history import HistoryManager
 from packaging.version import parse as parse_version
+from pytest_pretty import CustomTerminalReporter
 
 from napari.components import LayerList
 from napari.layers import Image, Labels, Points, Shapes, Vectors
-from napari.utils.config import async_loading
 from napari.utils.misc import ROOT_DIR
 
 if TYPE_CHECKING:
     from npe2._pytest_plugin import TestPluginManager
 
-
-def pytest_addoption(parser):
-    """Add napari specific command line options.
-
-    --aysnc_only
-        Run only asynchronous tests, not sync ones.
-
-    Notes
-    -----
-    Due to the placement of this conftest.py file, you must specifically name
-    the napari folder such as "pytest napari --aysnc_only"
-    """
-
-    parser.addoption(
-        "--async_only",
-        action="store_true",
-        default=False,
-        help="run only asynchronous tests",
-    )
+# touch ~/.Xauthority for Xlib support, must happen before importing pyautogui
+if os.getenv('CI') and sys.platform.startswith('linux'):
+    xauth = Path('~/.Xauthority').expanduser()
+    if not xauth.exists():
+        xauth.touch()
 
 
-@pytest.fixture
+@pytest.fixture()
 def layer_data_and_types():
     """Fixture that provides some layers and filenames
 
@@ -181,69 +173,19 @@ def layers():
     return LayerList(list_of_layers)
 
 
-# Currently we cannot run async and async in the invocation of pytest
-# because we get a segfault for unknown reasons. So for now:
-# "pytest" runs sync_only
-# "pytest napari --async_only" runs async only
-@pytest.fixture(scope="session", autouse=True)
-def configure_loading(request):
-    """Configure async/async loading."""
-    if request.config.getoption("--async_only"):
-        # Late import so we don't import experimental code unless using it.
-        from napari.components.experimental.chunk import synchronous_loading
-
-        with synchronous_loading(False):
-            yield
-    else:
-        yield  # Sync so do nothing.
-
-
-def _is_async_mode() -> bool:
-    """Return True if we are currently loading chunks asynchronously
-
-    Returns
-    -------
-    bool
-        True if we are currently loading chunks asynchronously.
-    """
-    if not async_loading:
-        return False  # Not enabled at all.
-
-    # Late import so we don't import experimental code unless using it.
-    from napari.components.experimental.chunk import chunk_loader
-
-    return not chunk_loader.force_synchronous
-
-
 @pytest.fixture(autouse=True)
-def skip_sync_only(request):
-    """Skip async_only tests if running async."""
-    sync_only = request.node.get_closest_marker('sync_only')
-    if _is_async_mode() and sync_only:
-        pytest.skip("running with --async_only")
-
-
-@pytest.fixture(autouse=True)
-def skip_async_only(request):
-    """Skip async_only tests if running sync."""
-    async_only = request.node.get_closest_marker('async_only')
-    if not _is_async_mode() and async_only:
-        pytest.skip("not running with --async_only")
-
-
-@pytest.fixture(autouse=True)
-def skip_examples(request):
+def _skip_examples(request):
     """Skip examples test if ."""
     if request.node.get_closest_marker(
         'examples'
-    ) and request.config.getoption("--skip_examples"):
-        pytest.skip("running with --skip_examples")
+    ) and request.config.getoption('--skip_examples'):
+        pytest.skip('running with --skip_examples')
 
 
 # _PYTEST_RAISE=1 will prevent pytest from handling exceptions.
 # Use with a debugger that's set to break on "unhandled exceptions".
 # https://github.com/pytest-dev/pytest/issues/7409
-if os.getenv('_PYTEST_RAISE', "0") != "0":
+if os.getenv('_PYTEST_RAISE', '0') != '0':
 
     @pytest.hookimpl(tryfirst=True)
     def pytest_exception_interact(call):
@@ -255,7 +197,7 @@ if os.getenv('_PYTEST_RAISE', "0") != "0":
 
 
 @pytest.fixture(autouse=True)
-def fresh_settings(monkeypatch):
+def _fresh_settings(monkeypatch):
     """This fixture ensures that default settings are used for every test.
 
     and ensures that changes to settings in a test are reverted, and never
@@ -281,11 +223,11 @@ def fresh_settings(monkeypatch):
 
     # this makes sure that we start with fresh settings for every test.
     settings._SETTINGS = None
-    yield
+    return
 
 
 @pytest.fixture(autouse=True)
-def auto_shutdown_dask_threadworkers():
+def _auto_shutdown_dask_threadworkers():
     """
     This automatically shutdown dask thread workers.
 
@@ -312,7 +254,7 @@ def auto_shutdown_dask_threadworkers():
 HistoryManager.enabled = False
 
 
-@pytest.fixture
+@pytest.fixture()
 def napari_svg_name():
     """the plugin name changes with npe2 to `napari-svg` from `svg`."""
     from importlib.metadata import version
@@ -323,37 +265,27 @@ def napari_svg_name():
     return 'napari-svg'
 
 
-@pytest.fixture(autouse=True, scope='session')
-def _no_error_reports():
-    """Turn off napari_error_reporter if it's installed."""
-    try:
-        p1 = patch('napari_error_reporter.capture_exception')
-        p2 = patch('napari_error_reporter.install_error_reporter')
-        with p1, p2:
-            yield
-    except (ModuleNotFoundError, AttributeError):
-        yield
-
-
 @pytest.fixture(autouse=True)
-def _npe2pm(npe2pm, monkeypatch):
-    """Autouse the npe2 mock plugin manager with no registered plugins."""
+def npe2pm_(npe2pm, monkeypatch):
+    """Autouse npe2 & npe1 mock plugin managers with no registered plugins."""
     from napari.plugins import NapariPluginManager
 
     monkeypatch.setattr(NapariPluginManager, 'discover', lambda *_, **__: None)
     return npe2pm
 
 
-@pytest.fixture
-def builtins(_npe2pm: TestPluginManager):
-    with _npe2pm.tmp_plugin(package='napari') as plugin:
+@pytest.fixture()
+def builtins(npe2pm_: TestPluginManager):
+    with npe2pm_.tmp_plugin(package='napari') as plugin:
         yield plugin
 
 
-@pytest.fixture
-def tmp_plugin(_npe2pm: TestPluginManager):
-    with _npe2pm.tmp_plugin() as plugin:
-        plugin.manifest.package_metadata = {'version': '0.1.0', 'name': 'test'}
+@pytest.fixture()
+def tmp_plugin(npe2pm_: TestPluginManager):
+    with npe2pm_.tmp_plugin() as plugin:
+        plugin.manifest.package_metadata = PackageMetadata(  # type: ignore[call-arg]
+            version='0.1.0', name='test'
+        )
         plugin.manifest.display_name = 'Temp Plugin'
         yield plugin
 
@@ -364,11 +296,11 @@ def _event_check(instance):
             if name in no_event:
                 assert not hasattr(
                     instance.events, name
-                ), f"event {name} defined"
+                ), f'event {name} defined'
             else:
                 assert hasattr(
                     instance.events, name
-                ), f"event {name} not defined"
+                ), f'event {name} not defined'
 
         return check
 
@@ -391,27 +323,40 @@ def pytest_generate_tests(metafunc):
         for obj in metafunc.cls.get_objects():
             for check, instance, name in _event_check(obj):
                 res.append((check, instance))
-                ids.append(f"{name}-{instance}")
+                ids.append(f'{name}-{instance}')
 
         metafunc.parametrize('event_define_check,obj', res, ids=ids)
 
 
 def pytest_collection_modifyitems(session, config, items):
+    test_subset = os.environ.get('NAPARI_TEST_SUBSET')
+
     test_order_prefix = [
-        os.path.join("napari", "utils"),
-        os.path.join("napari", "layers"),
-        os.path.join("napari", "components"),
-        os.path.join("napari", "settings"),
-        os.path.join("napari", "plugins"),
-        os.path.join("napari", "_vispy"),
-        os.path.join("napari", "_qt"),
-        os.path.join("napari", "qt"),
-        os.path.join("napari", "_tests"),
-        os.path.join("napari", "_tests", "test_examples.py"),
+        os.path.join('napari', 'utils'),
+        os.path.join('napari', 'layers'),
+        os.path.join('napari', 'components'),
+        os.path.join('napari', 'settings'),
+        os.path.join('napari', 'plugins'),
+        os.path.join('napari', '_vispy'),
+        os.path.join('napari', '_qt'),
+        os.path.join('napari', 'qt'),
+        os.path.join('napari', '_tests'),
+        os.path.join('napari', '_tests', 'test_examples.py'),
     ]
     test_order = [[] for _ in test_order_prefix]
     test_order.append([])  # for not matching tests
     for item in items:
+        if test_subset:
+            if test_subset.lower() == 'qt' and 'qapp' not in item.fixturenames:
+                # Skip non Qt tests
+                continue
+            if (
+                test_subset.lower() == 'headless'
+                and 'qapp' in item.fixturenames
+            ):
+                # Skip Qt tests
+                continue
+
         index = -1
         for i, prefix in enumerate(test_order_prefix):
             if prefix in str(item.fspath):
@@ -421,7 +366,7 @@ def pytest_collection_modifyitems(session, config, items):
 
 
 @pytest.fixture(autouse=True)
-def disable_notification_dismiss_timer(monkeypatch):
+def _disable_notification_dismiss_timer(monkeypatch):
     """
     This fixture disables starting timer for closing notification
     by setting the value of `NapariQtNotification.DISMISS_AFTER` to 0.
@@ -439,9 +384,9 @@ def disable_notification_dismiss_timer(monkeypatch):
     with suppress(ImportError):
         from napari._qt.dialogs.qt_notification import NapariQtNotification
 
-        monkeypatch.setattr(NapariQtNotification, "DISMISS_AFTER", 0)
-        monkeypatch.setattr(NapariQtNotification, "FADE_IN_RATE", 0)
-        monkeypatch.setattr(NapariQtNotification, "FADE_OUT_RATE", 0)
+        monkeypatch.setattr(NapariQtNotification, 'DISMISS_AFTER', 0)
+        monkeypatch.setattr(NapariQtNotification, 'FADE_IN_RATE', 0)
+        monkeypatch.setattr(NapariQtNotification, 'FADE_OUT_RATE', 0)
 
 
 @pytest.fixture()
@@ -451,39 +396,22 @@ def single_threaded_executor():
     executor.shutdown()
 
 
-@pytest.fixture(autouse=True)
-def _mock_app():
-    """Mock clean 'test_app' `NapariApplication` instance.
-
-    This is used whenever `napari._app_model.get_app()` is called to return
-    a 'test_app' `NapariApplication` instead of the 'napari'
-    `NapariApplication`.
-
-    Note that `NapariApplication` registers app-model actions, providers and
-    processors. If this is not desired, please create a clean
-    `app_model.Application` in the test. It does not however, register Qt
-    related actions or providers. If this is required for a unit test,
-    `napari._qt._qapp_model.qactions.init_qactions()` can be used within
-    the test.
-    """
-    from app_model import Application
-
-    from napari._app_model._app import NapariApplication, _napari_names
-
-    app = NapariApplication('test_app')
-    app.injection_store.namespace = _napari_names
-    with patch.object(NapariApplication, 'get_app', return_value=app):
+def _get_calling_stack():  # pragma: no cover
+    stack = []
+    for i in range(2, sys.getrecursionlimit()):
         try:
-            yield app
-        finally:
-            Application.destroy('test_app')
+            frame = sys._getframe(i)
+        except ValueError:
+            break
+        stack.append(f'{frame.f_code.co_filename}:{frame.f_lineno}')
+    return '\n'.join(stack)
 
 
-def _get_calling_place(depth=1):
-    if not hasattr(sys, "_getframe"):
-        return ""
+def _get_calling_place(depth=1):  # pragma: no cover
+    if not hasattr(sys, '_getframe'):
+        return ''
     frame = sys._getframe(1 + depth)
-    result = f"{frame.f_code.co_filename}:{frame.f_lineno}"
+    result = f'{frame.f_code.co_filename}:{frame.f_lineno}'
     if not frame.f_code.co_filename.startswith(ROOT_DIR):
         with suppress(ValueError):
             while not frame.f_code.co_filename.startswith(ROOT_DIR):
@@ -491,21 +419,21 @@ def _get_calling_place(depth=1):
                 if frame is None:
                     break
             else:
-                result += f" called from\n{frame.f_code.co_filename}:{frame.f_lineno}"
+                result += f' called from\n{frame.f_code.co_filename}:{frame.f_lineno}'
     return result
 
 
-@pytest.fixture
-def dangling_qthreads(monkeypatch, qtbot, request):
+@pytest.fixture()
+def _dangling_qthreads(monkeypatch, qtbot, request):
     from qtpy.QtCore import QThread
 
     base_start = QThread.start
     thread_dict = WeakKeyDictionary()
     # dict of threads that have been started but not yet terminated
 
-    if "disable_qthread_start" in request.keywords:
+    if 'disable_qthread_start' in request.keywords:
 
-        def my_start(*_, **__):
+        def my_start(self, priority=QThread.InheritPriority):
             """dummy function to prevent thread start"""
 
     else:
@@ -525,8 +453,8 @@ def dangling_qthreads(monkeypatch, qtbot, request):
                 dangling_threads_li.append((thread, calling))
         except RuntimeError as e:
             if (
-                "wrapped C/C++ object of type" not in e.args[0]
-                and "Internal C++ object" not in e.args[0]
+                'wrapped C/C++ object of type' not in e.args[0]
+                and 'Internal C++ object' not in e.args[0]
             ):
                 raise
 
@@ -536,36 +464,36 @@ def dangling_qthreads(monkeypatch, qtbot, request):
             qtbot.waitUntil(thread.isFinished, timeout=2000)
 
     long_desc = (
-        "If you see this error, it means that a QThread was started in a test "
-        "but not terminated. This can cause segfaults in the test suite. "
-        "Please use the `qtbot` fixture to wait for the thread to finish. "
-        "If you think that the thread is obsolete for this test, you can "
-        "use the `@pytest.mark.disable_qthread_start` mark or  `monkeypatch` "
-        "fixture to patch the `start` method of the "
-        "QThread class to do nothing.\n"
+        'If you see this error, it means that a QThread was started in a test '
+        'but not terminated. This can cause segfaults in the test suite. '
+        'Please use the `qtbot` fixture to wait for the thread to finish. '
+        'If you think that the thread is obsolete for this test, you can '
+        'use the `@pytest.mark.disable_qthread_start` mark or  `monkeypatch` '
+        'fixture to patch the `start` method of the '
+        'QThread class to do nothing.\n'
     )
 
     if len(dangling_threads_li) > 1:
-        long_desc += " The QThreads were started in:\n"
+        long_desc += ' The QThreads were started in:\n'
     else:
-        long_desc += " The QThread was started in:\n"
+        long_desc += ' The QThread was started in:\n'
 
-    assert not dangling_threads_li, long_desc + "\n".join(
+    assert not dangling_threads_li, long_desc + '\n'.join(
         x[1] for x in dangling_threads_li
     )
 
 
-@pytest.fixture
-def dangling_qthread_pool(monkeypatch, request):
+@pytest.fixture()
+def _dangling_qthread_pool(monkeypatch, request):
     from qtpy.QtCore import QThreadPool
 
     base_start = QThreadPool.start
     threadpool_dict = WeakKeyDictionary()
     # dict of threadpools that have been used to run QRunnables
 
-    if "disable_qthread_pool_start" in request.keywords:
+    if 'disable_qthread_pool_start' in request.keywords:
 
-        def my_start(*_, **__):
+        def my_start(self, runnable, priority=0):
             """dummy function to prevent thread start"""
 
     else:
@@ -582,6 +510,8 @@ def dangling_qthread_pool(monkeypatch, request):
     dangling_threads_pools = []
 
     for thread_pool, calling in threadpool_dict.items():
+        thread_pool.clear()
+        thread_pool.waitForDone(20)
         if thread_pool.activeThreadCount():
             dangling_threads_pools.append((thread_pool, calling))
 
@@ -591,36 +521,36 @@ def dangling_qthread_pool(monkeypatch, request):
             thread_pool.waitForDone(2000)
 
     long_desc = (
-        "If you see this error, it means that a QThreadPool was used to run "
-        "a QRunnable in a test but not terminated. This can cause segfaults "
-        "in the test suite. Please use the `qtbot` fixture to wait for the "
-        "thread to finish. If you think that the thread is obsolete for this "
-        "use the `@pytest.mark.disable_qthread_pool_start` mark or  `monkeypatch` "
-        "fixture to patch the `start` "
-        "method of the QThreadPool class to do nothing.\n"
+        'If you see this error, it means that a QThreadPool was used to run '
+        'a QRunnable in a test but not terminated. This can cause segfaults '
+        'in the test suite. Please use the `qtbot` fixture to wait for the '
+        'thread to finish. If you think that the thread is obsolete for this '
+        'use the `@pytest.mark.disable_qthread_pool_start` mark or  `monkeypatch` '
+        'fixture to patch the `start` '
+        'method of the QThreadPool class to do nothing.\n'
     )
     if len(dangling_threads_pools) > 1:
-        long_desc += " The QThreadPools were used in:\n"
+        long_desc += ' The QThreadPools were used in:\n'
     else:
-        long_desc += " The QThreadPool was used in:\n"
+        long_desc += ' The QThreadPool was used in:\n'
 
-    assert not dangling_threads_pools, long_desc + "\n".join(
-        "; ".join(x[1]) for x in dangling_threads_pools
+    assert not dangling_threads_pools, long_desc + '\n'.join(
+        '; '.join(x[1]) for x in dangling_threads_pools
     )
 
 
-@pytest.fixture
-def dangling_qtimers(monkeypatch, request):
+@pytest.fixture()
+def _dangling_qtimers(monkeypatch, request):
     from qtpy.QtCore import QTimer
 
     base_start = QTimer.start
     timer_dkt = WeakKeyDictionary()
     single_shot_list = []
 
-    if "disable_qtimer_start" in request.keywords:
+    if 'disable_qtimer_start' in request.keywords:
         from pytestqt.qt_compat import qt_api
 
-        def my_start(*_, **__):
+        def my_start(self, msec=None):
             """dummy function to prevent timer start"""
 
         _single_shot = my_start
@@ -632,13 +562,16 @@ def dangling_qtimers(monkeypatch, request):
                 else:
                     base_start(self)
 
-        monkeypatch.setattr(qt_api.QtCore, "QTimer", OldTimer)
+        monkeypatch.setattr(qt_api.QtCore, 'QTimer', OldTimer)
         # This monkeypatch is require to keep `qtbot.waitUntil` working
 
     else:
 
         def my_start(self, msec=None):
-            timer_dkt[self] = _get_calling_place()
+            calling_place = _get_calling_place()
+            if 'superqt' in calling_place and 'throttler' in calling_place:
+                calling_place += f' - {_get_calling_place(2)}'
+            timer_dkt[self] = calling_place
             if msec is not None:
                 base_start(self, msec)
             else:
@@ -651,6 +584,9 @@ def dangling_qtimers(monkeypatch, request):
                 t.timeout.connect(reciver)
             else:
                 t.timeout.connect(getattr(reciver, method))
+            calling_place = _get_calling_place(2)
+            if 'superqt' in calling_place and 'throttler' in calling_place:
+                calling_place += _get_calling_stack()
             single_shot_list.append((t, _get_calling_place(2)))
             base_start(t, msec)
 
@@ -676,27 +612,27 @@ def dangling_qtimers(monkeypatch, request):
             timer.stop()
 
     long_desc = (
-        "If you see this error, it means that a QTimer was started but not stopped. "
-        "This can cause tests to fail, and can also cause segfaults. "
-        "If this test does not require a QTimer to pass you could monkeypatch it out. "
-        "If it does require a QTimer, you should stop or wait for it to finish before test ends. "
+        'If you see this error, it means that a QTimer was started but not stopped. '
+        'This can cause tests to fail, and can also cause segfaults. '
+        'If this test does not require a QTimer to pass you could monkeypatch it out. '
+        'If it does require a QTimer, you should stop or wait for it to finish before test ends. '
     )
     if len(dangling_timers) > 1:
-        long_desc += "The QTimers were started in:\n"
+        long_desc += 'The QTimers were started in:\n'
     else:
-        long_desc += "The QTimer was started in:\n"
+        long_desc += 'The QTimer was started in:\n'
 
     def _check_throttle_info(path):
-        if "superqt" in path and "throttler" in path:
+        if 'superqt' in path and 'throttler' in path:
             return (
                 path
                 + " it's possible that there was a problem with unfinished work by a "
-                "qthrottler; to solve this, you can either try to wait (such as with "
-                "`qtbot.wait`) or disable throttling with the disable_throttling fixture"
+                'qthrottler; to solve this, you can either try to wait (such as with '
+                '`qtbot.wait`) or disable throttling with the disable_throttling fixture'
             )
         return path
 
-    assert not dangling_timers, long_desc + "\n".join(
+    assert not dangling_timers, long_desc + '\n'.join(
         _check_throttle_info(x[1]) for x in dangling_timers
     )
 
@@ -709,8 +645,8 @@ def _flush_mock(self):
     """There are no waiting events."""
 
 
-@pytest.fixture
-def disable_throttling(monkeypatch):
+@pytest.fixture()
+def _disable_throttling(monkeypatch):
     """Disable qthrottler from superqt.
 
     This is sometimes necessary to avoid flaky failures in tests
@@ -718,24 +654,24 @@ def disable_throttling(monkeypatch):
     """
     # if this monkeypath fails then you should update path to GenericSignalThrottler
     monkeypatch.setattr(
-        "superqt.utils._throttler.GenericSignalThrottler.throttle",
+        'superqt.utils._throttler.GenericSignalThrottler.throttle',
         _throttle_mock,
     )
     monkeypatch.setattr(
-        "superqt.utils._throttler.GenericSignalThrottler.flush", _flush_mock
+        'superqt.utils._throttler.GenericSignalThrottler.flush', _flush_mock
     )
 
 
-@pytest.fixture
-def dangling_qanimations(monkeypatch, request):
+@pytest.fixture()
+def _dangling_qanimations(monkeypatch, request):
     from qtpy.QtCore import QPropertyAnimation
 
     base_start = QPropertyAnimation.start
     animation_dkt = WeakKeyDictionary()
 
-    if "disable_qanimation_start" in request.keywords:
+    if 'disable_qanimation_start' in request.keywords:
 
-        def my_start(*_, **__):
+        def my_start(self):
             """dummy function to prevent thread start"""
 
     else:
@@ -758,32 +694,71 @@ def dangling_qanimations(monkeypatch, request):
             animation.stop()
 
     long_desc = (
-        "If you see this error, it means that a QPropertyAnimation was started but not stopped. "
-        "This can cause tests to fail, and can also cause segfaults. "
-        "If this test does not require a QPropertyAnimation to pass you could monkeypatch it out. "
-        "If it does require a QPropertyAnimation, you should stop or wait for it to finish before test ends. "
+        'If you see this error, it means that a QPropertyAnimation was started but not stopped. '
+        'This can cause tests to fail, and can also cause segfaults. '
+        'If this test does not require a QPropertyAnimation to pass you could monkeypatch it out. '
+        'If it does require a QPropertyAnimation, you should stop or wait for it to finish before test ends. '
     )
     if len(dangling_animations) > 1:
-        long_desc += " The QPropertyAnimations were started in:\n"
+        long_desc += ' The QPropertyAnimations were started in:\n'
     else:
-        long_desc += " The QPropertyAnimation was started in:\n"
-    assert not dangling_animations, long_desc + "\n".join(
+        long_desc += ' The QPropertyAnimation was started in:\n'
+    assert not dangling_animations, long_desc + '\n'.join(
         x[1] for x in dangling_animations
     )
 
 
 def pytest_runtest_setup(item):
-    if "qapp" in item.fixturenames:
+    if 'qapp' in item.fixturenames:
         # here we do autouse for dangling fixtures only if qapp is used
-        if "qtbot" not in item.fixturenames:
+        if 'qtbot' not in item.fixturenames:
             # for proper waiting for threads to finish
-            item.fixturenames.append("qtbot")
+            item.fixturenames.append('qtbot')
 
         item.fixturenames.extend(
             [
-                "dangling_qthread_pool",
-                "dangling_qanimations",
-                "dangling_qthreads",
-                "dangling_qtimers",
+                '_dangling_qthread_pool',
+                '_dangling_qanimations',
+                '_dangling_qthreads',
+                '_dangling_qtimers',
             ]
         )
+
+
+class NapariTerminalReporter(CustomTerminalReporter):
+    """
+    This ia s custom terminal reporter to how long it takes to finish given part of tests.
+    It prints time each time when test from different file is started.
+
+    It is created to be able to see if timeout is caused by long time execution, or it is just hanging.
+    """
+
+    currentfspath: Optional[Path]
+
+    def write_fspath_result(self, nodeid: str, res, **markup: bool) -> None:
+        if getattr(self, '_start_time', None) is None:
+            self._start_time = perf_counter()
+        fspath = self.config.rootpath / nodeid.split('::')[0]
+        if self.currentfspath is None or fspath != self.currentfspath:
+            if self.currentfspath is not None and self._show_progress_info:
+                self._write_progress_information_filling_space()
+                if os.environ.get('CI', False):
+                    self.write(
+                        f' [{timedelta(seconds=int(perf_counter() - self._start_time))}]'
+                    )
+            self.currentfspath = fspath
+            relfspath = bestrelpath(self.startpath, fspath)
+            self._tw.line()
+            self.write(relfspath + ' ')
+        self.write(res, flush=True, **markup)
+
+
+@pytest.hookimpl(trylast=True)
+def pytest_configure(config):
+    # Get the standard terminal reporter plugin and replace it with our
+    standard_reporter = config.pluginmanager.getplugin('terminalreporter')
+    custom_reporter = NapariTerminalReporter(config, sys.stdout)
+    if standard_reporter._session is not None:
+        custom_reporter._session = standard_reporter._session
+    config.pluginmanager.unregister(standard_reporter)
+    config.pluginmanager.register(custom_reporter, 'terminalreporter')
