@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Tuple
+from typing import TYPE_CHECKING
 
 import numpy as np
 from skimage.draw import line, polygon2mask
@@ -44,9 +44,9 @@ def inside_boxes(boxes):
     BCBM = np.multiply(BC, BM).sum(1)
     BCBC = np.multiply(BC, BC).sum(1)
 
-    c1 = 0 <= ABAM
+    c1 = ABAM >= 0
     c2 = ABAM <= ABAB
-    c3 = 0 <= BCBM
+    c3 = BCBM >= 0
     c4 = BCBM <= BCBC
 
     inside = np.all(np.array([c1, c2, c3, c4]), axis=0)
@@ -247,7 +247,7 @@ def orientation(p, q, r):
     return val
 
 
-def is_collinear(points):
+def is_collinear(points: npt.NDArray) -> bool:
     """Determines if a list of 2D points are collinear.
 
     Parameters
@@ -301,8 +301,11 @@ def point_to_lines(point, lines):
     norm_lines[reject] = 1
     unit_lines = lines_vectors / norm_lines
 
-    # calculate distance to line
-    line_dist = abs(np.cross(unit_lines, point_vectors))
+    # calculate distance to line (2D cross-product)
+    line_dist = abs(
+        unit_lines[..., 0] * point_vectors[..., 1]
+        - unit_lines[..., 1] * point_vectors[..., 0]
+    )
 
     # calculate scale
     line_loc = (unit_lines * point_vectors).sum(axis=1) / norm_lines.squeeze()
@@ -325,7 +328,7 @@ def point_to_lines(point, lines):
     return index, location
 
 
-def create_box(data):
+def create_box(data: npt.NDArray) -> npt.NDArray:
     """Creates the axis aligned interaction box of a list of points
 
     Parameters
@@ -362,7 +365,7 @@ def create_box(data):
     return box
 
 
-def rectangle_to_box(data):
+def rectangle_to_box(data: npt.NDArray) -> npt.NDArray:
     """Converts the four corners of a rectangle into a interaction box like
     representation. If the rectangle is not axis aligned the resulting box
     representation will not be axis aligned either
@@ -382,7 +385,7 @@ def rectangle_to_box(data):
     if not data.shape[0] == 4:
         raise ValueError(
             trans._(
-                "Data shape does not match expected `[4, D]` shape specifying corners for the rectangle",
+                'Data shape does not match expected `[4, D]` shape specifying corners for the rectangle',
                 deferred=True,
             )
         )
@@ -402,7 +405,7 @@ def rectangle_to_box(data):
     return box
 
 
-def find_corners(data):
+def find_corners(data: npt.NDArray) -> npt.NDArray:
     """Finds the four corners of the interaction box defined by an array of
     points
 
@@ -426,27 +429,31 @@ def find_corners(data):
     return corners
 
 
-def center_radii_to_corners(center, radii):
+def center_radii_to_corners(
+    center: npt.NDArray, radii: npt.NDArray
+) -> npt.NDArray:
     """Expands a center and radii into a four corner rectangle
 
     Parameters
     ----------
-    center : np.ndarray | list
-        Length 2 array or list of the center coordinates
-    radii : np.ndarray | list
-        Length 2 array or list of the two radii
+    center : np.ndarray
+        Length 2 array of the center coordinates.
+    radii : np.ndarray
+        Length 2 array of the two radii.
 
     Returns
     -------
     corners : np.ndarray
-        4x2 array of corners of the bounding box
+        4x2 array of corners of the bounding box.
     """
     data = np.array([center + radii, center - radii])
     corners = find_corners(data)
     return corners
 
 
-def triangulate_ellipse(corners, num_segments=100):
+def triangulate_ellipse(
+    corners: npt.NDArray, num_segments: int = 100
+) -> tuple[npt.NDArray, npt.NDArray]:
     """Determines the triangulation of a path. The resulting `offsets` can
     multiplied by a `width` scalar and be added to the resulting `centers`
     to generate the vertices of the triangles for the triangulation, i.e.
@@ -488,7 +495,7 @@ def triangulate_ellipse(corners, num_segments=100):
     if not corners.shape[0] == 4:
         raise ValueError(
             trans._(
-                "Data shape does not match expected `[4, D]` shape specifying corners for the ellipse",
+                'Data shape does not match expected `[4, D]` shape specifying corners for the ellipse',
                 deferred=True,
             )
         )
@@ -531,7 +538,7 @@ def triangulate_ellipse(corners, num_segments=100):
     return vertices, triangles
 
 
-def triangulate_face(data):
+def triangulate_face(data: npt.NDArray) -> tuple[npt.NDArray, npt.NDArray]:
     """Determines the triangulation of the face of a shape.
 
     Parameters
@@ -557,7 +564,7 @@ def triangulate_face(data):
         # connect last with first vertex
         edges[-1, 1] = 0
 
-        res = triangulate({"vertices": data, "segments": edges}, "p")
+        res = triangulate({'vertices': data, 'segments': edges}, 'p')
         vertices, triangles = res['vertices'], res['triangles']
     else:
         vertices, triangles = PolygonData(vertices=data).triangulate()
@@ -567,7 +574,9 @@ def triangulate_face(data):
     return vertices, triangles
 
 
-def triangulate_edge(path, closed=False):
+def triangulate_edge(
+    path: npt.NDArray, closed: bool = False
+) -> tuple[npt.NDArray, npt.NDArray, npt.NDArray]:
     """Determines the triangulation of a path. The resulting `offsets` can
     multiplied by a `width` scalar and be added to the resulting `centers`
     to generate the vertices of the triangles for the triangulation, i.e.
@@ -730,22 +739,29 @@ def generate_2D_edge_meshes(path, closed=False, limit=3, bevel=False):
     )[0]
 
     if len(idx_bevel) > 0:
-        # only the 'outwards sticking' offsets should be changed
-        # TODO: This is not entirely true as in extreme cases both can go to infinity
         idx_offset = (miter_signs[idx_bevel] < 0).astype(int)
-        idx_bevel_full = 2 * idx_bevel + idx_offset
+
+        # outside and inside offsets are treated differently (only outside offsets get beveled)
+        # See drawing at:
+        # https://github.com/napari/napari/pull/6706#discussion_r1528790407
+        idx_bevel_outside = 2 * idx_bevel + idx_offset
+        idx_bevel_inside = 2 * idx_bevel + (1 - idx_offset)
         sign_bevel = np.expand_dims(miter_signs[idx_bevel], -1)
 
-        # adjust offset of outer "left" vertex
-        offsets[idx_bevel_full] = (
+        # adjust offset of outer offset
+        offsets[idx_bevel_outside] = (
             -0.5 * full_normals[:-1][idx_bevel] * sign_bevel
         )
+        # adjust/normalize length of inner offset
+        offsets[idx_bevel_inside] /= np.sqrt(
+            miter_lengths_squared[idx_bevel, np.newaxis]
+        )
 
         # special cases for the last vertex
         _nonspecial = idx_bevel != len(path) - 1
 
         idx_bevel = idx_bevel[_nonspecial]
-        idx_bevel_full = idx_bevel_full[_nonspecial]
+        idx_bevel_outside = idx_bevel_outside[_nonspecial]
         sign_bevel = sign_bevel[_nonspecial]
         idx_offset = idx_offset[_nonspecial]
 
@@ -758,13 +774,12 @@ def generate_2D_edge_meshes(path, closed=False, limit=3, bevel=False):
         triangles[2 * idx_bevel, idx_offset] = len(centers) + np.arange(
             len(idx_bevel)
         )
-        triangles[
-            2 * idx_bevel + (1 - idx_offset), idx_offset
-        ] = n_centers + np.arange(len(idx_bevel))
+        triangles[2 * idx_bevel + (1 - idx_offset), idx_offset] = (
+            n_centers + np.arange(len(idx_bevel))
+        )
 
-        # add center triangle
+        # add a new center/bevel triangle
         triangles0 = np.tile(np.array([[0, 1, 2]]), (len(idx_bevel), 1))
-
         triangles_bevel = np.array(
             [
                 2 * idx_bevel + idx_offset,
@@ -772,7 +787,6 @@ def generate_2D_edge_meshes(path, closed=False, limit=3, bevel=False):
                 n_centers + np.arange(len(idx_bevel)),
             ]
         ).T
-
         # add all new centers, offsets, and triangles
         centers = np.concatenate([centers, centers_bevel])
         offsets = np.concatenate([offsets, offsets_bevel])
@@ -814,7 +828,7 @@ def generate_tube_meshes(path, closed=False, tube_points=10):
     """
     points = np.array(path).astype(float)
 
-    if closed and not np.all(points[0] == points[-1]):
+    if closed and not np.array_equal(points[0], points[-1]):
         points = np.concatenate([points, [points[0]]], axis=0)
 
     tangents, normals, binormals = _frenet_frames(points, closed)
@@ -858,7 +872,9 @@ def generate_tube_meshes(path, closed=False, tube_points=10):
     return centers, offsets, triangles
 
 
-def path_to_mask(mask_shape, vertices):
+def path_to_mask(
+    mask_shape: npt.NDArray, vertices: npt.NDArray
+) -> npt.NDArray[np.bool_]:
     """Converts a path to a boolean mask with `True` for points lying along
     each edge.
 
@@ -896,7 +912,9 @@ def path_to_mask(mask_shape, vertices):
     return mask
 
 
-def poly_to_mask(mask_shape, vertices):
+def poly_to_mask(
+    mask_shape: npt.ArrayLike, vertices: npt.ArrayLike
+) -> npt.NDArray[np.bool_]:
     """Converts a polygon to a boolean mask with `True` for points
     lying inside the shape. Uses the bounding box of the vertices to reduce
     computation time.
@@ -1007,11 +1025,11 @@ def extract_shape_type(data, shape_type=None):
         type of each shape in data, or None if none was passed
     """
     # Tuple for one shape or list of shapes with shape_type
-    if isinstance(data, Tuple):
+    if isinstance(data, tuple):
         shape_type = data[1]
         data = data[0]
     # List of (vertices, shape_type) tuples
-    elif len(data) != 0 and all(isinstance(datum, Tuple) for datum in data):
+    elif len(data) != 0 and all(isinstance(datum, tuple) for datum in data):
         shape_type = [datum[1] for datum in data]
         data = [datum[0] for datum in data]
     return data, shape_type
@@ -1032,7 +1050,7 @@ def get_default_shape_type(current_type):
     default_type : str
         default shape type
     """
-    default = "polygon"
+    default = 'polygon'
     if not current_type:
         return default
     first_type = current_type[0]
@@ -1138,7 +1156,7 @@ def validate_num_vertices(
         ):
             raise ValueError(
                 trans._(
-                    "{shape_type} {shape} has invalid number of vertices: {shape_length}.",
+                    '{shape_type} {shape} has invalid number of vertices: {shape_length}.',
                     deferred=True,
                     shape_type=shape_type,
                     shape=shape,
@@ -1171,12 +1189,14 @@ def perpendicular_distance(
     """
 
     if np.array_equal(line_start, line_end):
-        return np.linalg.norm(point - line_start)
+        return float(np.linalg.norm(point - line_start))
 
     t = np.dot(point - line_end, line_start - line_end) / np.dot(
         line_start - line_end, line_start - line_end
     )
-    return np.linalg.norm(t * (line_start - line_end) + line_end - point)
+    return float(
+        np.linalg.norm(t * (line_start - line_end) + line_end - point)
+    )
 
 
 def rdp(vertices: npt.NDArray, epsilon: float) -> npt.NDArray:
