@@ -2,7 +2,7 @@
 # from napari.utils.events import Event
 # from napari.utils.colormaps import AVAILABLE_COLORMAPS
 
-from typing import Dict, List, Union
+from typing import Any, Optional, Union
 from warnings import warn
 
 import numpy as np
@@ -24,27 +24,24 @@ class Tracks(Layer):
         Coordinates for N points in D+1 dimensions. ID,T,(Z),Y,X. The first
         axis is the integer ID of the track. D is either 3 or 4 for planar
         or volumetric timeseries respectively.
-    features : Dataframe-like
-        Features table where each row corresponds to a point and each column
-        is a feature.
-    properties : dict {str: array (N,)}, DataFrame
-        Properties for each point. Each property should be an array of length N,
-        where N is the number of points.
-    graph : dict {int: list}
-        Graph representing associations between tracks. Dictionary defines the
-        mapping between a track ID and the parents of the track. This can be
-        one (the track has one parent, and the parent has >=1 child) in the
-        case of track splitting, or more than one (the track has multiple
-        parents, but only one child) in the case of track merging.
-        See examples/tracks_3d_with_graph.py
+    affine : n-D array or napari.utils.transforms.Affine
+        (N+1, N+1) affine transformation matrix in homogeneous coordinates.
+        The first (N, N) entries correspond to a linear transform and
+        the final column is a length N translation vector and a 1 or a napari
+        `Affine` transform object. Applied as an extra transform on top of the
+        provided scale, rotate, and shear values.
+    axis_labels : tuple of str, optional
+        Dimension names of the layer data.
+        If not provided, axis_labels will be set to (..., 'axis -2', 'axis -1').
+    blending : str
+        One of a list of preset blending modes that determines how RGB and
+        alpha values of the layer visual get mixed. Allowed values are
+        {'opaque', 'translucent', and 'additive'}.
+    cache : bool
+        Whether slices of out-of-core datasets should be cached upon retrieval.
+        Currently, this only applies to dask arrays.
     color_by : str
         Track property (from property keys) by which to color vertices.
-    tail_width : float
-        Width of the track tails in pixels.
-    tail_length : float
-        Length of the positive (backward in time) tails in units of time.
-    head_length : float
-        Length of the positive (forward in time) tails in units of time.
     colormap : str
         Default colormap to use to set vertex colors. Specialized colormaps,
         relating to specified properties can be passed to the layer via
@@ -53,41 +50,56 @@ class Tracks(Layer):
         Optional dictionary mapping each property to a colormap for that
         property. This allows each property to be assigned a specific colormap,
         rather than having a global colormap for everything.
-    name : str
-        Name of the layer.
+    experimental_clipping_planes : list of dicts, list of ClippingPlane, or ClippingPlaneList
+        Each dict defines a clipping plane in 3D in data coordinates.
+        Valid dictionary keys are {'position', 'normal', and 'enabled'}.
+        Values on the negative side of the normal are discarded if the plane is enabled.
+    features : Dataframe-like
+        Features table where each row corresponds to a point and each column
+        is a feature.
+    graph : dict {int: list}
+        Graph representing associations between tracks. Dictionary defines the
+        mapping between a track ID and the parents of the track. This can be
+        one (the track has one parent, and the parent has >=1 child) in the
+        case of track splitting, or more than one (the track has multiple
+        parents, but only one child) in the case of track merging.
+        See examples/tracks_3d_with_graph.py
+    head_length : float
+        Length of the positive (forward in time) tails in units of time.
     metadata : dict
         Layer metadata.
-    scale : tuple of float
-        Scale factors for the layer.
-    translate : tuple of float
-        Translation values for the layer.
+    name : str
+        Name of the layer.
+    opacity : float
+        Opacity of the layer visual, between 0.0 and 1.0.
+    projection_mode : str
+        How data outside the viewed dimensions but inside the thick Dims slice will
+        be projected onto the viewed dimenions.
+    properties : dict {str: array (N,)}, DataFrame
+        Properties for each point. Each property should be an array of length N,
+        where N is the number of points.
     rotate : float, 3-tuple of float, or n-D array.
         If a float convert into a 2D rotation matrix using that value as an
         angle. If 3-tuple convert into a 3D rotation matrix, using a yaw,
         pitch, roll convention. Otherwise assume an nD rotation. Angles are
         assumed to be in degrees. They can be converted from radians with
         np.degrees if needed.
+    scale : tuple of float
+        Scale factors for the layer.
     shear : 1-D array or n-D array
         Either a vector of upper triangular values, or an nD shear matrix with
         ones along the main diagonal.
-    affine : n-D array or napari.utils.transforms.Affine
-        (N+1, N+1) affine transformation matrix in homogeneous coordinates.
-        The first (N, N) entries correspond to a linear transform and
-        the final column is a length N translation vector and a 1 or a napari
-        `Affine` transform object. Applied as an extra transform on top of the
-        provided scale, rotate, and shear values.
-    opacity : float
-        Opacity of the layer visual, between 0.0 and 1.0.
-    blending : str
-        One of a list of preset blending modes that determines how RGB and
-        alpha values of the layer visual get mixed. Allowed values are
-        {'opaque', 'translucent', and 'additive'}.
+    tail_length : float
+        Length of the positive (backward in time) tails in units of time.
+    tail_width : float
+        Width of the track tails in pixels.
+    translate : tuple of float
+        Translation values for the layer.
+    units : tuple of str or pint.Unit, optional
+        Units of the layer data in world coordinates.
+        If not provided, the default units are assumed to be pixels.
     visible : bool
         Whether the layer visual is currently being displayed.
-    cache : bool
-        Whether slices of out-of-core datasets should be cached upon retrieval.
-        Currently, this only applies to dask arrays.
-
     """
 
     # The max number of tracks that will ever be used to render the thumbnail
@@ -98,27 +110,30 @@ class Tracks(Layer):
         self,
         data,
         *,
-        features=None,
-        properties=None,
-        graph=None,
-        tail_width=2,
-        tail_length=30,
-        head_length=0,
-        name=None,
-        metadata=None,
-        scale=None,
-        translate=None,
-        rotate=None,
-        shear=None,
         affine=None,
-        opacity=1,
+        axis_labels=None,
         blending='additive',
-        visible=True,
-        colormap='turbo',
-        color_by='track_id',
-        colormaps_dict=None,
         cache=True,
+        color_by='track_id',
+        colormap='turbo',
+        colormaps_dict=None,
         experimental_clipping_planes=None,
+        features=None,
+        graph=None,
+        head_length: int = 0,
+        metadata=None,
+        name=None,
+        opacity=1.0,
+        projection_mode='none',
+        properties=None,
+        rotate=None,
+        scale=None,
+        shear=None,
+        tail_length: int = 30,
+        tail_width: int = 2,
+        translate=None,
+        units=None,
+        visible=True,
     ) -> None:
         # if not provided with any data, set up an empty layer in 2D+t
         # otherwise convert the data to an np.ndarray
@@ -130,18 +145,21 @@ class Tracks(Layer):
         super().__init__(
             data,
             ndim,
-            name=name,
-            metadata=metadata,
-            scale=scale,
-            translate=translate,
-            rotate=rotate,
-            shear=shear,
             affine=affine,
-            opacity=opacity,
+            axis_labels=axis_labels,
             blending=blending,
-            visible=visible,
             cache=cache,
             experimental_clipping_planes=experimental_clipping_planes,
+            name=name,
+            metadata=metadata,
+            opacity=opacity,
+            projection_mode=projection_mode,
+            rotate=rotate,
+            scale=scale,
+            shear=shear,
+            translate=translate,
+            units=units,
+            visible=visible,
         )
 
         self.events.add(
@@ -159,8 +177,9 @@ class Tracks(Layer):
         )
 
         # track manager deals with data slicing, graph building and properties
-        self._manager = TrackManager()
-        self._track_colors = None
+        self._manager = TrackManager(data)
+
+        self._track_colors: Optional[np.ndarray] = None
         self._colormaps_dict = colormaps_dict or {}  # additional colormaps
         self._color_by = color_by  # default color by ID
         self._colormap = colormap
@@ -216,12 +235,12 @@ class Tracks(Layer):
         """Determine number of dimensions of the layer."""
         return self._manager.ndim
 
-    def _get_state(self):
+    def _get_state(self) -> dict[str, Any]:
         """Get dictionary of layer state.
 
         Returns
         -------
-        state : dict
+        state : dict of str to Any
             Dictionary of layer state.
         """
         state = self._get_base_state()
@@ -344,7 +363,7 @@ class Tracks(Layer):
     def current_time(self):
         """current time according to the first dimension"""
         # TODO(arl): get the correct index here
-        time_step = self._slice_indices[0]
+        time_step = self._data_slice.point[0]
 
         if isinstance(time_step, slice):
             # if we are visualizing all time, then just set to the maximum
@@ -407,70 +426,72 @@ class Tracks(Layer):
     @features.setter
     def features(
         self,
-        features: Union[Dict[str, np.ndarray], pd.DataFrame],
+        features: Union[dict[str, np.ndarray], pd.DataFrame],
     ) -> None:
         self._manager.features = features
         self._check_color_by_in_features()
         self.events.properties()
 
     @property
-    def properties(self) -> Dict[str, np.ndarray]:
+    def properties(self) -> dict[str, np.ndarray]:
         """dict {str: np.ndarray (N,)}: Properties for each track."""
         return self._manager.properties
 
-    @property
-    def properties_to_color_by(self) -> List[str]:
-        """track properties that can be used for coloring etc..."""
-        return list(self.properties.keys())
-
     @properties.setter
-    def properties(self, properties: Dict[str, np.ndarray]):
+    def properties(self, properties: dict[str, np.ndarray]):
         """set track properties"""
         self.features = properties
 
     @property
-    def graph(self) -> Dict[int, Union[int, List[int]]]:
+    def properties_to_color_by(self) -> list[str]:
+        """track properties that can be used for coloring etc..."""
+        return list(self.properties.keys())
+
+    @property
+    def graph(self) -> Optional[dict[int, list[int]]]:
         """dict {int: list}: Graph representing associations between tracks."""
         return self._manager.graph
 
     @graph.setter
-    def graph(self, graph: Dict[int, Union[int, List[int]]]):
+    def graph(self, graph: dict[int, Union[int, list[int]]]):
         """Set the track graph."""
-        self._manager.graph = graph
+        # Ignored type, because mypy can't handle different signatures
+        # on getters and setters; see https://github.com/python/mypy/issues/3004
+        self._manager.graph = graph  # type: ignore[assignment]
         self._manager.build_graph()
         self.events.rebuild_graph()
 
     @property
-    def tail_width(self) -> Union[int, float]:
+    def tail_width(self) -> float:
         """float: Width for all vectors in pixels."""
         return self._tail_width
 
     @tail_width.setter
-    def tail_width(self, tail_width: Union[int, float]):
-        self._tail_width = np.clip(tail_width, 0.5, self._max_width)
+    def tail_width(self, tail_width: float):
+        self._tail_width: float = np.clip(tail_width, 0.5, self._max_width)
         self.events.tail_width()
 
     @property
-    def tail_length(self) -> Union[int, float]:
+    def tail_length(self) -> int:
         """float: Width for all vectors in pixels."""
         return self._tail_length
 
     @tail_length.setter
-    def tail_length(self, tail_length: Union[int, float]):
+    def tail_length(self, tail_length: int):
         if tail_length > self._max_length:
             self._max_length = tail_length
-        self._tail_length = tail_length
+        self._tail_length: int = tail_length
         self.events.tail_length()
 
     @property
-    def head_length(self) -> Union[int, float]:
+    def head_length(self) -> int:
         return self._head_length
 
     @head_length.setter
-    def head_length(self, head_length: Union[int, float]):
+    def head_length(self, head_length: int):
         if head_length > self._max_length:
             self._max_length = head_length
-        self._head_length = head_length
+        self._head_length: int = head_length
         self.events.head_length()
 
     @property
@@ -543,11 +564,13 @@ class Tracks(Layer):
         self.events.colormap()
 
     @property
-    def colormaps_dict(self) -> Dict[str, Colormap]:
+    def colormaps_dict(self) -> dict[str, Colormap]:
         return self._colormaps_dict
 
-    @colormaps_dict.setter
-    def colomaps_dict(self, colormaps_dict: Dict[str, Colormap]):
+    # Ignored type because mypy doesn't recognise colormaps_dict as a property
+    # TODO: investigate and fix this - not sure why this is the case?
+    @colormaps_dict.setter  # type: ignore[attr-defined]
+    def colomaps_dict(self, colormaps_dict: dict[str, Colormap]):
         # validate the dictionary entries?
         self._colormaps_dict = colormaps_dict
 
@@ -578,12 +601,12 @@ class Tracks(Layer):
         self._track_colors = colormap.map(vertex_properties)
 
     @property
-    def track_connex(self) -> np.ndarray:
+    def track_connex(self) -> Optional[np.ndarray]:
         """vertex connections for drawing track lines"""
         return self._manager.track_connex
 
     @property
-    def track_colors(self) -> np.ndarray:
+    def track_colors(self) -> Optional[np.ndarray]:
         """return the vertex colors according to the currently selected
         property"""
         return self._track_colors
@@ -594,12 +617,12 @@ class Tracks(Layer):
         return self._manager.graph_connex
 
     @property
-    def track_times(self) -> np.ndarray:
+    def track_times(self) -> Optional[np.ndarray]:
         """time points associated with each track vertex"""
         return self._manager.track_times
 
     @property
-    def graph_times(self) -> np.ndarray:
+    def graph_times(self) -> Optional[np.ndarray]:
         """time points associated with each graph vertex"""
         return self._manager.graph_times
 
@@ -620,7 +643,7 @@ class Tracks(Layer):
             warn(
                 (
                     trans._(
-                        "Previous color_by key {key!r} not present in features. Falling back to track_id",
+                        'Previous color_by key {key!r} not present in features. Falling back to track_id',
                         deferred=True,
                         key=self._color_by,
                     )
