@@ -3,7 +3,15 @@ from __future__ import annotations
 import functools
 import inspect
 import warnings
-from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
+from collections.abc import Sequence
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    NamedTuple,
+    Optional,
+    Union,
+)
 
 import dask
 import numpy as np
@@ -14,13 +22,46 @@ from napari.utils.events.custom_types import Array
 from napari.utils.transforms import Affine
 from napari.utils.translations import trans
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    import numpy.typing as npt
+
+    from napari.layers._data_protocols import LayerDataProtocol
+
+
+class Extent(NamedTuple):
+    """Extent of coordinates in a local data space and world space.
+
+    Each extent is a (2, D) array that stores the minimum and maximum coordinate
+    values in each of D dimensions. Both the minimum and maximum coordinates are
+    inclusive so form an axis-aligned, closed interval or a D-dimensional box
+    around all the coordinates.
+
+    Attributes
+    ----------
+    data : (2, D) array of floats
+        The minimum and maximum raw data coordinates ignoring any transforms like
+        translation or scale.
+    world : (2, D) array of floats
+        The minimum and maximum world coordinates after applying a transform to the
+        raw data coordinates that brings them into a potentially shared world space.
+    step : (D,) array of floats
+        The step in each dimension that when taken from the minimum world coordinate,
+        should form a regular grid that eventually hits the maximum world coordinate.
+    """
+
+    data: np.ndarray
+    world: np.ndarray
+    step: np.ndarray
+
 
 def register_layer_action(
     keymapprovider,
     description: str,
     repeatable: bool = False,
-    shortcuts: str = None,
-):
+    shortcuts: Optional[Union[str, list[str]]] = None,
+) -> Callable[[Callable], Callable]:
     """
     Convenient decorator to register an action with the current Layers
 
@@ -49,7 +90,7 @@ def register_layer_action(
 
     """
 
-    def _inner(func):
+    def _inner(func: Callable) -> Callable:
         nonlocal shortcuts
         name = 'napari:' + func.__name__
 
@@ -76,7 +117,7 @@ def register_layer_attr_action(
     description: str,
     attribute_name: str,
     shortcuts=None,
-):
+) -> Callable[[Callable], Callable]:
     """
     Convenient decorator to register an action with the current Layers.
     This will get and restore attribute from function first argument.
@@ -105,14 +146,14 @@ def register_layer_attr_action(
 
     """
 
-    def _handle(func):
+    def _handle(func: Callable) -> Callable:
         sig = inspect.signature(func)
         try:
             first_variable_name = next(iter(sig.parameters))
         except StopIteration as e:
             raise RuntimeError(
                 trans._(
-                    "If actions has no arguments there is no way to know what to set the attribute to.",
+                    'If actions has no arguments there is no way to know what to set the attribute to.',
                     deferred=True,
                 ),
             ) from e
@@ -163,7 +204,9 @@ def _nanmax(array):
     return max_value
 
 
-def calc_data_range(data, rgb=False):
+def calc_data_range(
+    data: LayerDataProtocol, rgb: bool = False
+) -> tuple[float, float]:
     """Calculate range of data values. If all values are equal return [0, 1].
 
     Parameters
@@ -175,8 +218,8 @@ def calc_data_range(data, rgb=False):
 
     Returns
     -------
-    values : list of float
-        Range of values.
+    values : pair of floats
+        Minimum and maximum values in that order.
 
     Notes
     -----
@@ -184,8 +227,18 @@ def calc_data_range(data, rgb=False):
     returned.
     """
     if data.dtype == np.uint8:
-        return [0, 255]
+        return (0, 255)
 
+    if isinstance(data, np.ndarray) and data.ndim < 3:
+        min_val = _nanmin(data)
+        max_val = _nanmax(data)
+        if min_val == max_val:
+            min_val = min(min_val, 0)
+            max_val = max(max_val, 1)
+        return float(min_val), float(max_val)
+
+    center: Union[int, list[int]]
+    reduced_data: Union[list, LayerDataProtocol]
     if data.size > 1e7 and (data.ndim == 1 or (rgb and data.ndim == 2)):
         # If data is very large take the average of start, middle and end.
         center = int(data.shape[0] // 2)
@@ -233,12 +286,12 @@ def calc_data_range(data, rgb=False):
     max_val = _nanmax(reduced_data)
 
     if min_val == max_val:
-        min_val = 0
-        max_val = 1
-    return [float(min_val), float(max_val)]
+        min_val = min(min_val, 0)
+        max_val = max(max_val, 1)
+    return (float(min_val), float(max_val))
 
 
-def segment_normal(a, b, p=(0, 0, 1)):
+def segment_normal(a, b, p=(0, 0, 1)) -> np.ndarray:
     """Determines the unit normal of the vector from a to b.
 
     Parameters
@@ -258,6 +311,8 @@ def segment_normal(a, b, p=(0, 0, 1)):
     """
     d = b - a
 
+    norm: Any  # float or array or float, mypy has some difficulities.
+
     if d.ndim == 1:
         normal = np.array([d[1], -d[0]]) if len(d) == 2 else np.cross(d, p)
         norm = np.linalg.norm(normal)
@@ -272,9 +327,7 @@ def segment_normal(a, b, p=(0, 0, 1)):
         norm = np.linalg.norm(normal, axis=1, keepdims=True)
         ind = norm == 0
         norm[ind] = 1
-    unit_norm = normal / norm
-
-    return unit_norm
+    return normal / norm
 
 
 def convert_to_uint8(data: np.ndarray) -> np.ndarray:
@@ -299,17 +352,17 @@ def convert_to_uint8(data: np.ndarray) -> np.ndarray:
     if data.dtype == out_dtype:
         return data
     in_kind = data.dtype.kind
-    if in_kind == "b":
+    if in_kind == 'b':
         return data.astype(out_dtype) * 255
-    if in_kind == "f":
+    if in_kind == 'f':
         image_out = np.multiply(data, out_max, dtype=data.dtype)
         np.rint(image_out, out=image_out)
         np.clip(image_out, 0, out_max, out=image_out)
         image_out = np.nan_to_num(image_out, copy=False)
         return image_out.astype(out_dtype)
 
-    if in_kind in "ui":
-        if in_kind == "u":
+    if in_kind in 'ui':
+        if in_kind == 'u':
             if data.max() < out_max:
                 return data.astype(out_dtype)
             return np.right_shift(data, (data.dtype.itemsize - 1) * 8).astype(
@@ -324,87 +377,14 @@ def convert_to_uint8(data: np.ndarray) -> np.ndarray:
         return np.right_shift(data, (data.dtype.itemsize - 1) * 8 - 1).astype(
             out_dtype
         )
-    return None
-
-
-def prepare_properties(
-    properties: Optional[Union[Dict[str, Array], pd.DataFrame]],
-    choices: Optional[Dict[str, Array]] = None,
-    num_data: int = 0,
-    save_choices: bool = False,
-) -> Tuple[Dict[str, np.ndarray], Dict[str, np.ndarray]]:
-    """Prepare properties and choices into standard forms.
-    Parameters
-    ----------
-    properties : dict[str, Array] or DataFrame
-        The property values.
-    choices : dict[str, Array]
-        The property value choices.
-    num_data : int
-        The length of data that the properties represent (e.g. number of points).
-    save_choices : bool
-        If true, always return all of the properties in choices.
-    Returns
-    -------
-    properties: dict[str, np.ndarray]
-        A dictionary where the key is the property name and the value
-        is an ndarray of property values.
-    choices: dict[str, np.ndarray]
-        A dictionary where the key is the property name and the value
-        is an ndarray of unique property value choices.
-    """
-    # If there is no data, non-empty properties represent choices as a deprecated behavior.
-    if num_data == 0 and properties:
-        warnings.warn(
-            trans._(
-                "Property choices should be passed as property_choices, not properties. This warning will become an error in version 0.4.11.",
-            ),
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        choices = properties
-        properties = {}
-
-    properties = validate_properties(properties, expected_len=num_data)
-    choices = _validate_property_choices(choices)
-
-    # Populate the new choices by using the property keys and merging the
-    # corresponding unique property and choices values.
-    new_choices = {
-        k: np.unique(np.concatenate((v, choices.get(k, []))))
-        for k, v in properties.items()
-    }
-
-    # If there are no properties, and thus no new choices, populate new choices
-    # from the input choices, and initialize property values as missing or empty.
-    if len(new_choices) == 0:
-        new_choices = {k: np.unique(v) for k, v in choices.items()}
-        if len(new_choices) > 0:
-            if num_data > 0:
-                properties = {
-                    k: np.array([None] * num_data) for k in new_choices
-                }
-            else:
-                properties = {
-                    k: np.empty(0, v.dtype) for k, v in new_choices.items()
-                }
-
-    # For keys that are in the input choices, but not in the new choices,
-    # sometimes add appropriate array values to new choices and properties.
-    if save_choices:
-        for k, v in choices.items():
-            if k not in new_choices:
-                new_choices[k] = np.unique(v)
-                properties[k] = np.array([None] * num_data)
-
-    return properties, new_choices
+    raise NotImplementedError
 
 
 def get_current_properties(
-    properties: Dict[str, np.ndarray],
-    choices: Dict[str, np.ndarray],
+    properties: dict[str, np.ndarray],
+    choices: dict[str, np.ndarray],
     num_data: int = 0,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Get the current property values from the properties or choices.
 
     Parameters
@@ -436,7 +416,7 @@ def get_current_properties(
 
 def dataframe_to_properties(
     dataframe: pd.DataFrame,
-) -> Dict[str, np.ndarray]:
+) -> dict[str, np.ndarray]:
     """Convert a dataframe to a properties dictionary.
     Parameters
     ----------
@@ -452,9 +432,9 @@ def dataframe_to_properties(
 
 
 def validate_properties(
-    properties: Optional[Union[Dict[str, Array], pd.DataFrame]],
+    properties: Optional[Union[dict[str, Array], pd.DataFrame]],
     expected_len: Optional[int] = None,
-) -> Dict[str, np.ndarray]:
+) -> dict[str, np.ndarray]:
     """Validate the type and size of properties and coerce values to numpy arrays.
     Parameters
     ----------
@@ -479,7 +459,7 @@ def validate_properties(
     if any(v != expected_len for v in lens):
         raise ValueError(
             trans._(
-                "the number of items must be equal for all properties",
+                'the number of items must be equal for all properties',
                 deferred=True,
             )
         )
@@ -494,7 +474,7 @@ def _validate_property_choices(property_choices):
 
 
 def _coerce_current_properties_value(
-    value: Union[float, str, bool, list, tuple, np.ndarray]
+    value: Union[float, str, bool, list, tuple, np.ndarray],
 ) -> np.ndarray:
     """Coerce a value in a current_properties dictionary into the correct type.
 
@@ -524,10 +504,10 @@ def _coerce_current_properties_value(
 
 
 def coerce_current_properties(
-    current_properties: Dict[
-        str, Union[float, str, int, bool, list, tuple, np.ndarray]
-    ]
-) -> Dict[str, np.ndarray]:
+    current_properties: Mapping[
+        str, Union[float, str, int, bool, list, tuple, npt.NDArray]
+    ],
+) -> dict[str, np.ndarray]:
     """Coerce a current_properties dictionary into the correct type.
 
 
@@ -623,7 +603,12 @@ def compute_multiscale_level_and_corners(
     return level, corners
 
 
-def coerce_affine(affine, *, ndim, name=None):
+def coerce_affine(
+    affine: Union[npt.ArrayLike, Affine],
+    *,
+    ndim: int,
+    name: Optional[str] = None,
+) -> Affine:
     """Coerce a user input into an affine transform object.
 
     If the input is already an affine transform object, that same object is returned
@@ -664,10 +649,10 @@ def coerce_affine(affine, *, ndim, name=None):
 
 
 def dims_displayed_world_to_layer(
-    dims_displayed_world: List[int],
+    dims_displayed_world: list[int],
     ndim_world: int,
     ndim_layer: int,
-) -> List[int]:
+) -> list[int]:
     """Convert the dims_displayed from world dims to the layer dims.
 
     This accounts differences in the number of dimensions in the world
@@ -691,11 +676,13 @@ def dims_displayed_world_to_layer(
     else:
         order = dims_displayed_world
     offset = ndim_world - ndim_layer
-    order = np.array(order)
+
+    order_arr = np.array(order)
     if offset <= 0:
-        order = list(range(-offset)) + list(order - offset)
+        order = list(range(-offset)) + list(order_arr - offset)
     else:
-        order = list(order[order >= offset] - offset)
+        order = list(order_arr[order_arr >= offset] - offset)
+
     n_display_world = len(dims_displayed_world)
     if n_display_world > ndim_layer:
         n_display_layer = ndim_layer
@@ -706,7 +693,11 @@ def dims_displayed_world_to_layer(
     return dims_displayed
 
 
-def get_extent_world(data_extent, data_to_world, centered=False):
+def get_extent_world(
+    data_extent: npt.NDArray,
+    data_to_world: Affine,
+    centered: Optional[Any] = None,
+) -> npt.NDArray:
     """Range of layer in world coordinates base on provided data_extent
 
     Parameters
@@ -715,19 +706,23 @@ def get_extent_world(data_extent, data_to_world, centered=False):
         Extent of layer in data coordinates.
     data_to_world : napari.utils.transforms.Affine
         The transform from data to world coordinates.
-    centered : bool
-        If pixels should be centered. By default False.
 
     Returns
     -------
     extent_world : array, shape (2, D)
     """
-    D = data_extent.shape[1]
-    # subtract 0.5 to get from pixel center to pixel edge
-    offset = 0.5 * bool(centered)
-    pixel_extents = tuple(d - offset for d in data_extent.T)
+    if centered is not None:
+        warnings.warn(
+            trans._(
+                'The `centered` argument is deprecated. '
+                'Extents are now always centered on data points.',
+                deferred=True,
+            ),
+            stacklevel=2,
+        )
 
-    full_data_extent = np.array(np.meshgrid(*pixel_extents)).T.reshape(-1, D)
+    D = data_extent.shape[1]
+    full_data_extent = np.array(np.meshgrid(*data_extent.T)).T.reshape(-1, D)
     full_world_extent = data_to_world(full_data_extent)
     world_extent = np.array(
         [
@@ -779,10 +774,10 @@ class _FeatureTable:
 
     def __init__(
         self,
-        values: Optional[Union[Dict[str, np.ndarray], pd.DataFrame]] = None,
+        values: Optional[Union[dict[str, np.ndarray], pd.DataFrame]] = None,
         *,
         num_data: Optional[int] = None,
-        defaults: Optional[Union[Dict[str, Any], pd.DataFrame]] = None,
+        defaults: Optional[Union[dict[str, Any], pd.DataFrame]] = None,
     ) -> None:
         self._values = _validate_features(values, num_data=num_data)
         self._defaults = _validate_feature_defaults(defaults, self._values)
@@ -803,12 +798,12 @@ class _FeatureTable:
         return self._defaults
 
     def set_defaults(
-        self, defaults: Union[Dict[str, Any], pd.DataFrame]
+        self, defaults: Union[dict[str, Any], pd.DataFrame]
     ) -> None:
         """Sets the feature default values."""
         self._defaults = _validate_feature_defaults(defaults, self._values)
 
-    def properties(self) -> Dict[str, np.ndarray]:
+    def properties(self) -> dict[str, np.ndarray]:
         """Converts this to a deprecated properties dictionary.
 
         This will reference the features data when possible, but in general the
@@ -821,7 +816,7 @@ class _FeatureTable:
         """
         return _features_to_properties(self._values)
 
-    def choices(self) -> Dict[str, np.ndarray]:
+    def choices(self) -> dict[str, np.ndarray]:
         """Converts this to a deprecated property choices dictionary.
 
         Only categorical features will have corresponding entries in the dictionary.
@@ -837,15 +832,15 @@ class _FeatureTable:
             if isinstance(series.dtype, pd.CategoricalDtype)
         }
 
-    def currents(self) -> Dict[str, np.ndarray]:
+    def currents(self) -> dict[str, np.ndarray]:
         """Converts the defaults table to a deprecated current properties dictionary."""
         return _features_to_properties(self._defaults)
 
     def set_currents(
         self,
-        currents: Dict[str, np.ndarray],
+        currents: dict[str, npt.NDArray],
         *,
-        update_indices: Optional[List[int]] = None,
+        update_indices: Optional[list[int]] = None,
     ) -> None:
         """Sets the default values using the deprecated current properties dictionary.
 
@@ -914,12 +909,12 @@ class _FeatureTable:
     def from_layer(
         cls,
         *,
-        features: Optional[Union[Dict[str, np.ndarray], pd.DataFrame]] = None,
-        feature_defaults: Optional[Union[Dict[str, Any], pd.DataFrame]] = None,
+        features: Optional[Union[dict[str, np.ndarray], pd.DataFrame]] = None,
+        feature_defaults: Optional[Union[dict[str, Any], pd.DataFrame]] = None,
         properties: Optional[
-            Union[Dict[str, np.ndarray], pd.DataFrame]
+            Union[dict[str, np.ndarray], pd.DataFrame]
         ] = None,
-        property_choices: Optional[Dict[str, np.ndarray]] = None,
+        property_choices: Optional[dict[str, np.ndarray]] = None,
         num_data: Optional[int] = None,
     ) -> _FeatureTable:
         """Coerces a layer's keyword arguments to a feature manager.
@@ -976,7 +971,7 @@ def _get_default_column(column: pd.Series) -> pd.Series:
 
 
 def _validate_features(
-    features: Optional[Union[Dict[str, np.ndarray], pd.DataFrame]],
+    features: Optional[Union[dict[str, np.ndarray], pd.DataFrame]],
     *,
     num_data: Optional[int] = None,
 ) -> pd.DataFrame:
@@ -994,15 +989,13 @@ def _validate_features(
         # a pandas Series with mixed indices as input.
         # This way should handle all array-like objects correctly.
         # See https://github.com/napari/napari/pull/4755 for more details.
-        features = {
-            key: np.array(value, copy=False) for key, value in features.items()
-        }
+        features = {key: np.asarray(value) for key, value in features.items()}
     index = None if num_data is None else range(num_data)
     return pd.DataFrame(data=features, index=index)
 
 
 def _validate_feature_defaults(
-    defaults: Optional[Union[Dict[str, Any], pd.DataFrame]],
+    defaults: Optional[Union[dict[str, Any], pd.DataFrame]],
     values: pd.DataFrame,
 ) -> pd.DataFrame:
     """Validates and coerces feature default values into a pandas DataFrame.
@@ -1050,8 +1043,8 @@ def _validate_feature_defaults(
 
 def _features_from_properties(
     *,
-    properties: Optional[Union[Dict[str, np.ndarray], pd.DataFrame]] = None,
-    property_choices: Optional[Dict[str, np.ndarray]] = None,
+    properties: Optional[Union[dict[str, np.ndarray], pd.DataFrame]] = None,
+    property_choices: Optional[dict[str, np.ndarray]] = None,
     num_data: Optional[int] = None,
 ) -> pd.DataFrame:
     """Validates and coerces deprecated properties input into a features DataFrame.
@@ -1073,7 +1066,7 @@ def _features_from_properties(
     return _validate_features(properties, num_data=num_data)
 
 
-def _features_to_properties(features: pd.DataFrame) -> Dict[str, np.ndarray]:
+def _features_to_properties(features: pd.DataFrame) -> dict[str, np.ndarray]:
     """Converts a features DataFrame to a deprecated properties dictionary.
 
     See Also
