@@ -1,18 +1,19 @@
 from __future__ import annotations
 
 import itertools
-from typing import TYPE_CHECKING, List
+from typing import TYPE_CHECKING
 
 import numpy as np
+import pint
 
-from ...layers import Image
-from ...layers.image._image_utils import guess_multiscale
-from ...utils.colormaps import CYMRGB, MAGENTA_GREEN, Colormap
-from ...utils.misc import ensure_iterable, ensure_sequence_of_iterables
-from ...utils.translations import trans
+from napari.layers import Image
+from napari.layers.image._image_utils import guess_multiscale
+from napari.utils.colormaps import CYMRGB, MAGENTA_GREEN, Colormap
+from napari.utils.misc import ensure_iterable, ensure_sequence_of_iterables
+from napari.utils.translations import trans
 
 if TYPE_CHECKING:
-    from ...types import FullLayerData
+    from napari.types import FullLayerData
 
 
 def slice_from_axis(array, *, axis, element):
@@ -44,7 +45,7 @@ def split_channels(
     data: np.ndarray,
     channel_axis: int,
     **kwargs,
-) -> List[FullLayerData]:
+) -> list[FullLayerData]:
     """Split the data array into separate arrays along an axis.
 
     Keyword arguments will override any parameters altered or set in this
@@ -87,13 +88,15 @@ def split_channels(
     kwargs.setdefault('colormap', None)
     # these arguments are *already* iterables in the single-channel case.
     iterable_kwargs = {
+        'axis_labels',
         'scale',
         'translate',
-        'affine',
         'contrast_limits',
         'metadata',
         'plane',
         'experimental_clipping_planes',
+        'custom_interpolation_kernel_2d',
+        'units',
     }
 
     # turn the kwargs dict into a mapping of {key: iterator}
@@ -121,10 +124,15 @@ def split_channels(
                     allow_none=True,
                 )
             )
+        elif key == 'affine' and isinstance(val, np.ndarray):
+            # affine may be Affine or np.ndarray object that is not
+            # iterable, but it is not now a problem as we use it only to warning
+            # if a provided object is a sequence and channel_axis is not provided
+            kwargs[key] = itertools.repeat(val, n_channels)
         else:
             kwargs[key] = iter(ensure_iterable(val))
 
-    layerdata_list = list()
+    layerdata_list = []
     for i in range(n_channels):
         if multiscale:
             image = [
@@ -137,7 +145,7 @@ def split_channels(
         for key, val in kwargs.items():
             try:
                 i_kwargs[key] = next(val)
-            except StopIteration:
+            except StopIteration as e:
                 raise IndexError(
                     trans._(
                         "Error adding multichannel image with data shape {data_shape!r}.\nRequested channel_axis ({channel_axis}) had length {n_channels}, but the '{key}' argument only provided {i} values. ",
@@ -148,15 +156,15 @@ def split_channels(
                         key=key,
                         i=i,
                     )
-                )
+                ) from e
 
-        layerdata = (image, i_kwargs, 'image')
+        layerdata: FullLayerData = (image, i_kwargs, 'image')
         layerdata_list.append(layerdata)
 
     return layerdata_list
 
 
-def stack_to_images(stack: Image, axis: int, **kwargs) -> List[Image]:
+def stack_to_images(stack: Image, axis: int, **kwargs) -> list[Image]:
     """Splits a single Image layer into a list layers along axis.
 
     Some image layer properties will be changed unless specified as an item in
@@ -184,7 +192,7 @@ def stack_to_images(stack: Image, axis: int, **kwargs) -> List[Image]:
 
     data, meta, _ = stack.as_layer_data_tuple()
 
-    for key in ("contrast_limits", "colormap", "blending"):
+    for key in ('contrast_limits', 'colormap', 'blending'):
         del meta[key]
 
     name = stack.name
@@ -193,7 +201,7 @@ def stack_to_images(stack: Image, axis: int, **kwargs) -> List[Image]:
     if num_dim < 3:
         raise ValueError(
             trans._(
-                "The image needs more than 2 dimensions for splitting",
+                'The image needs more than 2 dimensions for splitting',
                 deferred=True,
             )
         )
@@ -208,7 +216,7 @@ def stack_to_images(stack: Image, axis: int, **kwargs) -> List[Image]:
             )
         )
 
-    if kwargs.get("colormap"):
+    if kwargs.get('colormap'):
         kwargs['colormap'] = itertools.cycle(kwargs['colormap'])
 
     if meta['rgb']:
@@ -226,6 +234,8 @@ def stack_to_images(stack: Image, axis: int, **kwargs) -> List[Image]:
     meta['rotate'] = None
     meta['shear'] = None
     meta['affine'] = None
+    meta['axis_labels'] = None
+    meta['units'] = None
 
     meta.update(kwargs)
     imagelist = []
@@ -240,7 +250,7 @@ def stack_to_images(stack: Image, axis: int, **kwargs) -> List[Image]:
     return imagelist
 
 
-def split_rgb(stack: Image, with_alpha=False) -> List[Image]:
+def split_rgb(stack: Image, with_alpha=False) -> list[Image]:
     """Variant of stack_to_images that splits an RGB with predefined cmap."""
     if not stack.rgb:
         raise ValueError(
@@ -251,7 +261,7 @@ def split_rgb(stack: Image, with_alpha=False) -> List[Image]:
     return images if with_alpha else images[:3]
 
 
-def images_to_stack(images: List[Image], axis: int = 0, **kwargs) -> Image:
+def images_to_stack(images: list[Image], axis: int = 0, **kwargs) -> Image:
     """Combines a list of Image layers into one layer stacked along axis
 
     The new image layer will get the meta properties of the first
@@ -274,22 +284,24 @@ def images_to_stack(images: List[Image], axis: int = 0, **kwargs) -> Image:
     """
 
     if not images:
-        raise IndexError(trans._("images list is empty", deferred=True))
+        raise IndexError(trans._('images list is empty', deferred=True))
 
     data, meta, _ = images[0].as_layer_data_tuple()
 
-    kwargs.setdefault("scale", np.insert(meta['scale'], axis, 1))
-    kwargs.setdefault("translate", np.insert(meta['translate'], axis, 0))
+    kwargs.setdefault('scale', np.insert(meta['scale'], axis, 1))
+    kwargs.setdefault('translate', np.insert(meta['translate'], axis, 0))
 
     meta.update(kwargs)
+    meta['units'] = (pint.get_application_registry().pixel,) + meta['units']
+    meta['axis_labels'] = (f'axis -{data.ndim + 1}',) + meta['axis_labels']
     new_data = np.stack([image.data for image in images], axis=axis)
     return Image(new_data, **meta)
 
 
-def merge_rgb(images: List[Image]) -> List[Image]:
+def merge_rgb(images: list[Image]) -> Image:
     """Variant of images_to_stack that makes an RGB from 3 images."""
     if not (len(images) == 3 and all(isinstance(x, Image) for x in images)):
         raise ValueError(
-            trans._("merge_rgb requires 3 images layers", deferred=True)
+            trans._('merge_rgb requires 3 images layers', deferred=True)
         )
     return images_to_stack(images, axis=-1, rgb=True)
