@@ -5,12 +5,13 @@ from enum import IntFlag
 from fnmatch import fnmatch
 from functools import lru_cache
 from pathlib import Path
-from typing import Dict, Iterable, List, Optional, Set, Tuple, Union
+from typing import Optional, Union
 
 from npe2 import PluginManifest
 
 from napari.plugins import _npe2, plugin_manager
 from napari.settings import get_settings
+from napari.types import PathLike
 
 
 class MatchFlag(IntFlag):
@@ -21,7 +22,7 @@ class MatchFlag(IntFlag):
 
 
 @lru_cache
-def score_specificity(pattern: str) -> Tuple[bool, int, List[MatchFlag]]:
+def score_specificity(pattern: str) -> tuple[bool, int, list[MatchFlag]]:
     """Score an fnmatch pattern, with higher specificities having lower scores.
 
     Absolute paths have highest specificity,
@@ -45,7 +46,7 @@ def score_specificity(pattern: str) -> Tuple[bool, int, List[MatchFlag]]:
     pattern = osp.normpath(pattern)
 
     segments = pattern.split(osp.sep)
-    score: List[MatchFlag] = []
+    score: list[MatchFlag] = []
     ends_with_star = False
 
     def add(match_flag):
@@ -70,7 +71,7 @@ def score_specificity(pattern: str) -> Tuple[bool, int, List[MatchFlag]]:
     return not osp.isabs(pattern), 1 - len(score), score
 
 
-def _get_preferred_readers(path: str) -> Iterable[Tuple[str, str]]:
+def _get_preferred_readers(path: PathLike) -> list[tuple[str, str]]:
     """Given filepath, find matching readers from preferences.
 
     Parameters
@@ -80,18 +81,24 @@ def _get_preferred_readers(path: str) -> Iterable[Tuple[str, str]]:
 
     Returns
     -------
-    filtered_preferences : Iterable[Tuple[str, str]]
+    filtered_preferences : List[Tuple[str, str]]
         Filtered patterns and their corresponding readers.
     """
+    path = str(path)
 
     if osp.isdir(path) and not path.endswith(os.sep):
         path = path + os.sep
 
     reader_settings = get_settings().plugins.extension2reader
-    return filter(lambda kv: fnmatch(path, kv[0]), reader_settings.items())
+
+    def filter_fn(kv: tuple[str, str]) -> bool:
+        return fnmatch(path, kv[0])
+
+    ret = list(filter(filter_fn, reader_settings.items()))
+    return ret
 
 
-def get_preferred_reader(path: str) -> Optional[str]:
+def get_preferred_reader(path: PathLike) -> Optional[str]:
     """Given filepath, find the best matching reader from the preferences.
 
     Parameters
@@ -115,7 +122,7 @@ def get_preferred_reader(path: str) -> Optional[str]:
     return None
 
 
-def get_potential_readers(filename: str) -> Dict[str, str]:
+def get_potential_readers(filename: PathLike) -> dict[str, str]:
     """Given filename, returns all readers that may read the file.
 
     Original plugin engine readers are checked based on returning
@@ -140,7 +147,7 @@ def get_potential_readers(filename: str) -> Dict[str, str]:
     return readers
 
 
-def get_all_readers() -> Tuple[Dict[str, str], Dict[str, str]]:
+def get_all_readers() -> tuple[dict[str, str], dict[str, str]]:
     """
     Return a dict of all npe2 readers and one of all npe1 readers
 
@@ -164,7 +171,7 @@ def normalized_name(name: str) -> str:
     Normalize a plugin name by replacing underscores and dots by dashes and
     lower casing it.
     """
-    return re.sub(r"[-_.]+", "-", name).lower()
+    return re.sub(r'[-_.]+', '-', name).lower()
 
 
 def get_filename_patterns_for_reader(plugin_name: str):
@@ -183,7 +190,7 @@ def get_filename_patterns_for_reader(plugin_name: str):
     set
         set of filename patterns accepted by all plugin's reader contributions
     """
-    all_fn_patterns: Set[str] = set()
+    all_fn_patterns: set[str] = set()
     current_plugin: Union[PluginManifest, None] = None
     for manifest in _npe2.iter_manifests():
         if manifest.name == plugin_name:
