@@ -1,4 +1,5 @@
 """Tests for the settings manager."""
+
 import os
 from pathlib import Path
 
@@ -11,7 +12,7 @@ from napari.settings import CURRENT_SCHEMA_VERSION, NapariSettings
 from napari.utils.theme import get_theme, register_theme
 
 
-@pytest.fixture
+@pytest.fixture()
 def test_settings(tmp_path):
     """A fixture that can be used to test and save settings"""
     from napari.settings import NapariSettings
@@ -45,23 +46,23 @@ def test_settings_file_not_created(test_settings):
 
 
 def test_settings_loads(tmp_path):
-    data = "appearance:\n   theme: light"
+    data = 'appearance:\n   theme: light'
     fake_path = tmp_path / 'fake_path.yml'
     fake_path.write_text(data)
-    assert NapariSettings(fake_path).appearance.theme == "light"
+    assert NapariSettings(fake_path).appearance.theme == 'light'
 
 
 def test_settings_load_invalid_content(tmp_path):
     # This is invalid content
 
     fake_path = tmp_path / 'fake_path.yml'
-    fake_path.write_text(":")
+    fake_path.write_text(':')
     NapariSettings(fake_path)
 
 
 def test_settings_load_invalid_type(tmp_path, caplog):
     # The invalid data will be replaced by the default value
-    data = "appearance:\n   theme: 1"
+    data = 'appearance:\n   theme: 1'
     fake_path = tmp_path / 'fake_path.yml'
     fake_path.write_text(data)
     assert NapariSettings(fake_path).application.save_window_geometry is True
@@ -71,7 +72,7 @@ def test_settings_load_invalid_type(tmp_path, caplog):
 def test_settings_load_strict(tmp_path, monkeypatch):
     # use Config.strict_config_check to enforce good config files
     monkeypatch.setattr(NapariSettings.__config__, 'strict_config_check', True)
-    data = "appearance:\n   theme: 1"
+    data = 'appearance:\n   theme: 1'
     fake_path = tmp_path / 'fake_path.yml'
     fake_path.write_text(data)
     with pytest.raises(ValidationError):
@@ -82,7 +83,8 @@ def test_settings_load_invalid_key(tmp_path, monkeypatch):
     # The invalid key will be removed
 
     fake_path = tmp_path / 'fake_path.yml'
-    data = """
+    data = f"""
+    schema_version: {CURRENT_SCHEMA_VERSION}
     application:
        non_existing_key: [1, 2]
        first_time: false
@@ -91,7 +93,7 @@ def test_settings_load_invalid_key(tmp_path, monkeypatch):
 
     monkeypatch.setattr(os, 'environ', {})
     s = NapariSettings(fake_path)
-    assert getattr(s, "non_existing_key", None) is None
+    assert getattr(s, 'non_existing_key', None) is None
     s.save()
     text = fake_path.read_text()
     # removed bad key
@@ -103,21 +105,22 @@ def test_settings_load_invalid_key(tmp_path, monkeypatch):
 
 def test_settings_load_invalid_section(tmp_path):
     # The invalid section will be removed from the file
-    data = "non_existing_section:\n   foo: bar"
+    data = 'non_existing_section:\n   foo: bar'
 
     fake_path = tmp_path / 'fake_path.yml'
     fake_path.write_text(data)
 
     settings_ = NapariSettings(fake_path)
-    assert getattr(settings_, "non_existing_section", None) is None
+    assert getattr(settings_, 'non_existing_section', None) is None
 
 
 def test_settings_to_dict(test_settings):
     data_dict = test_settings.dict()
-    assert isinstance(data_dict, dict) and data_dict.get("application")
+    assert isinstance(data_dict, dict)
+    assert data_dict.get('application')
 
     data_dict = test_settings.dict(exclude_defaults=True)
-    assert not data_dict.get("application")
+    assert not data_dict.get('application')
 
 
 def test_settings_to_dict_no_env(monkeypatch):
@@ -126,7 +129,7 @@ def test_settings_to_dict_no_env(monkeypatch):
     assert s.dict()['appearance']['theme'] == 'light'
     assert s.dict(exclude_env=True)['appearance']['theme'] == 'light'
 
-    monkeypatch.setenv("NAPARI_APPEARANCE_THEME", 'light')
+    monkeypatch.setenv('NAPARI_APPEARANCE_THEME', 'light')
     s = NapariSettings(None)
     assert s.dict()['appearance']['theme'] == 'light'
     assert 'theme' not in s.dict(exclude_env=True).get('appearance', {})
@@ -136,11 +139,11 @@ def test_settings_reset(test_settings):
     appearance_id = id(test_settings.appearance)
     test_settings.reset()
     assert id(test_settings.appearance) == appearance_id
-    assert test_settings.appearance.theme == "dark"
-    test_settings.appearance.theme = "light"
-    assert test_settings.appearance.theme == "light"
+    assert test_settings.appearance.theme == 'dark'
+    test_settings.appearance.theme = 'light'
+    assert test_settings.appearance.theme == 'light'
     test_settings.reset()
-    assert test_settings.appearance.theme == "dark"
+    assert test_settings.appearance.theme == 'dark'
     assert id(test_settings.appearance) == appearance_id
 
 
@@ -151,25 +154,25 @@ def test_settings_model(test_settings):
 
     with pytest.raises(ValidationError):
         # Should be a valid string
-        test_settings.appearance.theme = "vaporwave"
+        test_settings.appearance.theme = 'vaporwave'
 
 
 def test_custom_theme_settings(test_settings):
     # See: https://github.com/napari/napari/issues/2340
-    custom_theme_name = "_test_blue_"
+    custom_theme_name = '_test_blue_'
 
     # No theme registered yet, this should fail
     with pytest.raises(ValidationError):
         test_settings.appearance.theme = custom_theme_name
 
-    blue_theme = get_theme('dark', True)
+    blue_theme = get_theme('dark').to_rgb_dict()
     blue_theme.update(
         background='rgb(28, 31, 48)',
         foreground='rgb(45, 52, 71)',
         primary='rgb(80, 88, 108)',
         current='rgb(184, 112, 0)',
     )
-    register_theme(custom_theme_name, blue_theme, "test")
+    register_theme(custom_theme_name, blue_theme, 'test')
 
     # Theme registered, should pass validation
     test_settings.appearance.theme = custom_theme_name
@@ -196,7 +199,7 @@ def test_model_fields_are_annotated(test_settings):
             )
 
     if errors:
-        raise ValueError("\n\n".join(errors))
+        raise ValueError('\n\n'.join(errors))
 
 
 def test_settings_env_variables(monkeypatch):
@@ -214,7 +217,7 @@ def test_settings_env_variables(monkeypatch):
     # can also use json in nested vars
     assert NapariSettings(None).plugins.extension2reader == {}
     monkeypatch.setenv('NAPARI_PLUGINS_EXTENSION2READER', '{"*.zarr": "hi"}')
-    assert NapariSettings(None).plugins.extension2reader == {"*.zarr": "hi"}
+    assert NapariSettings(None).plugins.extension2reader == {'*.zarr': 'hi'}
 
 
 def test_settings_env_variables_fails(monkeypatch):
@@ -233,14 +236,14 @@ def test_subfield_env_field(monkeypatch):
     class T(NapariSettings):
         sub: Sub
 
-    monkeypatch.setenv("VARNAME", '42')
+    monkeypatch.setenv('VARNAME', '42')
     assert T(sub={}).sub.x == 42
 
 
 # Failing because dark is actually the default...
 def test_settings_env_variables_do_not_write_to_disk(tmp_path, monkeypatch):
     # create a settings file with light theme
-    data = "appearance:\n   theme: light"
+    data = 'appearance:\n   theme: light'
     fake_path = tmp_path / 'fake_path.yml'
     fake_path.write_text(data)
 
@@ -248,7 +251,7 @@ def test_settings_env_variables_do_not_write_to_disk(tmp_path, monkeypatch):
     disk_settings = fake_path.read_text()
     assert 'theme: light' in disk_settings
     # make sure they load correctly
-    assert NapariSettings(fake_path).appearance.theme == "light"
+    assert NapariSettings(fake_path).appearance.theme == 'light'
 
     # now load settings again with an Env-var override
     monkeypatch.setenv('NAPARI_APPEARANCE_THEME', 'dark')
@@ -268,7 +271,7 @@ def test_settings_env_variables_do_not_write_to_disk(tmp_path, monkeypatch):
 
     # and it's back if we reread without the env var override
     monkeypatch.delenv('NAPARI_APPEARANCE_THEME')
-    assert NapariSettings(fake_path).appearance.theme == "light"
+    assert NapariSettings(fake_path).appearance.theme == 'light'
 
 
 def test_settings_only_saves_non_default_values(monkeypatch, tmp_path):
@@ -278,7 +281,7 @@ def test_settings_only_saves_non_default_values(monkeypatch, tmp_path):
     monkeypatch.setattr(os, 'environ', {})
 
     # manually get all default data and write to yaml file
-    all_data = NapariSettings(None).yaml()
+    all_data = NapariSettings(schema_version=CURRENT_SCHEMA_VERSION).yaml()
     fake_path = tmp_path / 'fake_path.yml'
     assert 'appearance' in all_data
     assert 'application' in all_data
@@ -302,11 +305,11 @@ def test_get_settings(tmp_path):
 def test_get_settings_fails(monkeypatch, tmp_path):
     p = f'{tmp_path}.yaml'
     settings.get_settings(p)
-    with pytest.raises(Exception) as e:
+    with pytest.raises(
+        RuntimeError, match='The path can only be set once per session'
+    ):
         settings.get_settings(p)
 
-    assert 'The path can only be set once per session' in str(e)
-
 
 def test_first_time():
     """This test just confirms that we don't load an existing file (locally)"""
@@ -326,8 +329,8 @@ def test_no_save_path():
     s = NapariSettings(config_path=None)
     assert s.config_path is None
 
-    with pytest.raises(ValueError):
-        # the original `save()` method is patched in conftest.fresh_settings
+    with pytest.raises(ValueError, match='No path provided'):
+        # the original `save()` method is patched in conftest._fresh_settings
         # so we "unmock" it here to assert the failure
         NapariSettings.__original_save__(s)  # type: ignore
 
@@ -357,3 +360,32 @@ def test_full_serialize(test_settings: NapariSettings, tmp_path, ext):
     Should work with both json and yaml.
     """
     test_settings.save(tmp_path / f't.{ext}', exclude_defaults=False)
+
+
+def test_shortcut_aliases():
+    """Check that Command, Option, Super, Cmd are all valid modifiers."""
+    settings_original = NapariSettings(
+        schema_version='0.6.0',
+        shortcuts={
+            'shortcuts': {
+                'napari:focus_axes_up': ['Option-Up'],
+                'napari:roll_axes': ['Super-E'],
+                'napari:transpose_axes': ['Control-Alt-T'],
+                'napari:paste_shape': ['V', 'Command-T'],
+                'napari:reset_view': ['Cmd-R'],
+            }
+        },
+    )
+    settings_canonical = NapariSettings(
+        schema_version='0.6.0',
+        shortcuts={
+            'shortcuts': {
+                'napari:focus_axes_up': ['Alt+Up'],
+                'napari:roll_axes': ['Meta+E'],
+                'napari:transpose_axes': ['Ctrl+Alt+T'],
+                'napari:paste_shape': ['V', 'Meta+T'],
+                'napari:reset_view': ['Meta+R'],
+            }
+        },
+    )
+    assert settings_original == settings_canonical
