@@ -5,7 +5,7 @@ from collections import defaultdict
 from dataclasses import dataclass
 from functools import cached_property
 from inspect import isgeneratorfunction
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Callable, Optional
 
 from napari.utils.events import EmitterGroup
 from napari.utils.interactions import Shortcut
@@ -18,14 +18,12 @@ if TYPE_CHECKING:
     from napari.utils.key_bindings import KeymapProvider
 
     class SignalInstance(Protocol):
-        def connect(self, callback: Callable) -> None:
-            ...
+        def connect(self, callback: Callable) -> None: ...
 
     class Button(Protocol):
         clicked: SignalInstance
 
-        def setToolTip(self, text: str) -> None:
-            ...
+        def setToolTip(self, text: str) -> None: ...
 
     class ShortcutEvent:
         name: str
@@ -78,13 +76,13 @@ class ActionManager:
     in.
     """
 
-    _actions: Dict[str, Action]
+    _actions: dict[str, Action]
 
     def __init__(self) -> None:
         # map associating a name/id with a Comm
-        self._actions: Dict[str, Action] = {}
-        self._shortcuts: Dict[str, List[str]] = defaultdict(list)
-        self._stack: List[str] = []
+        self._actions: dict[str, Action] = {}
+        self._shortcuts: dict[str, list[str]] = defaultdict(list)
+        self._stack: list[str] = []
         self._tooltip_include_action_name = False
         self.events = EmitterGroup(source=self, shorcut_changed=None)
 
@@ -216,7 +214,9 @@ class ActionManager:
         """
         self._validate_action_name(name)
 
-        if (action := self._actions.get(name)) and isgeneratorfunction(action):
+        if (action := self._actions.get(name)) and isgeneratorfunction(
+            getattr(action, 'command', None)
+        ):
             raise ValueError(
                 trans._(
                     '`bind_button` cannot be used with generator functions',
@@ -224,7 +224,10 @@ class ActionManager:
                 )
             )
 
-        button.clicked.connect(lambda: self.trigger(name))
+        def _trigger():
+            self.trigger(name)
+
+        button.clicked.connect(_trigger)
         if name in self._actions:
             button.setToolTip(
                 f'{self._build_tooltip(name)} {extra_tooltip_text}'
@@ -263,7 +266,7 @@ class ActionManager:
         self._update_shortcut_bindings(name)
         self._emit_shortcut_change(name, shortcut)
 
-    def unbind_shortcut(self, name: str) -> Optional[List[str]]:
+    def unbind_shortcut(self, name: str) -> Optional[list[str]]:
         """
         Unbind all shortcuts for a given action name.
 
@@ -289,7 +292,7 @@ class ActionManager:
         if action is None:
             warnings.warn(
                 trans._(
-                    "Attempting to unbind an action which does not exists ({name}), this may have no effects. This can happen if your settings are out of date, if you upgraded napari, upgraded or deactivated a plugin, or made a typo in in your custom keybinding.",
+                    'Attempting to unbind an action which does not exists ({name}), this may have no effects. This can happen if your settings are out of date, if you upgraded napari, upgraded or deactivated a plugin, or made a typo in in your custom keybinding.',
                     name=name,
                 ),
                 UserWarning,
@@ -316,7 +319,7 @@ class ActionManager:
 
         if name in self._shortcuts:
             jstr = ' ' + trans._p('<keysequence> or <keysequence>', 'or') + ' '
-            shorts = jstr.join(f"{Shortcut(s)}" for s in self._shortcuts[name])
+            shorts = jstr.join(f'{Shortcut(s)}' for s in self._shortcuts[name])
             ttip += f' ({shorts})'
 
         ttip += f'[{name}]' if self._tooltip_include_action_name else ''
@@ -344,9 +347,9 @@ class ActionManager:
                 action = self._actions.get(name, None)
                 if action and layer == action.keymapprovider:
                     for shortcut in shortcuts:
-                        layer_shortcuts[layer][
-                            str(shortcut)
-                        ] = action.description
+                        layer_shortcuts[layer][str(shortcut)] = (
+                            action.description
+                        )
 
         return layer_shortcuts
 
