@@ -1,13 +1,16 @@
-from typing import Any, Dict, Union
+from typing import Any, Union
 
 import numpy as np
-from pydantic import validator
 
-from ...utils.events import EventedModel
-from ...utils.events.custom_types import Array
-from ..translations import trans
-from .categorical_colormap_utils import ColorCycle, compare_colormap_dicts
-from .standardize_color import transform_color
+from napari._pydantic_compat import Field
+from napari.utils.color import ColorValue
+from napari.utils.colormaps.categorical_colormap_utils import (
+    ColorCycle,
+    compare_colormap_dicts,
+)
+from napari.utils.colormaps.standardize_color import transform_color
+from napari.utils.events import EventedModel
+from napari.utils.translations import trans
 
 
 class CategoricalColormap(EventedModel):
@@ -25,12 +28,10 @@ class CategoricalColormap(EventedModel):
         The default value is a cycle of all white.
     """
 
-    colormap: Dict[Any, Array[np.float32, (4,)]] = {}
-    fallback_color: ColorCycle = ColorCycle.validate_type('white')
-
-    @validator('colormap', pre=True)
-    def _standardize_colormap(cls, v):
-        return {k: transform_color(v)[0] for k, v in v.items()}
+    colormap: dict[Any, ColorValue] = Field(default_factory=dict)
+    fallback_color: ColorCycle = Field(
+        default_factory=lambda: ColorCycle.validate_type('white')
+    )
 
     def map(self, color_properties: Union[list, np.ndarray]) -> np.ndarray:
         """Map an array of values to an array of colors
@@ -50,7 +51,7 @@ class CategoricalColormap(EventedModel):
 
         # add properties if they are not in the colormap
         color_cycle_keys = [*self.colormap]
-        props_in_map = np.in1d(color_properties, color_cycle_keys)
+        props_in_map = np.isin(color_properties, color_cycle_keys)
         if not np.all(props_in_map):
             new_prop_values = color_properties[np.logical_not(props_in_map)]
             indices_to_add = np.unique(new_prop_values, return_index=True)[1]
@@ -59,7 +60,7 @@ class CategoricalColormap(EventedModel):
             ]
             for prop in props_to_add:
                 new_color = next(self.fallback_color.cycle)
-                self.colormap[prop] = np.squeeze(transform_color(new_color))
+                self.colormap[prop] = ColorValue(new_color)
         # map the colors
         colors = np.array([self.colormap[x] for x in color_properties])
         return colors
@@ -78,10 +79,7 @@ class CategoricalColormap(EventedModel):
                 }
             else:
                 colormap = {}
-            if 'fallback_color' in params:
-                fallback_color = params['fallback_color']
-            else:
-                fallback_color = 'white'
+            fallback_color = params.get('fallback_color', 'white')
         else:
             colormap = {k: transform_color(v)[0] for k, v in params.items()}
             fallback_color = 'white'
@@ -96,17 +94,17 @@ class CategoricalColormap(EventedModel):
     def validate_type(cls, val):
         if isinstance(val, cls):
             return val
-        if isinstance(val, list) or isinstance(val, np.ndarray):
+        if isinstance(val, (list, np.ndarray)):
             return cls.from_array(val)
-        elif isinstance(val, dict):
+        if isinstance(val, dict):
             return cls.from_dict(val)
-        else:
-            raise TypeError(
-                trans._(
-                    'colormap should be an array or dict',
-                    deferred=True,
-                )
+
+        raise TypeError(
+            trans._(
+                'colormap should be an array or dict',
+                deferred=True,
             )
+        )
 
     def __eq__(self, other):
         if isinstance(other, CategoricalColormap):
@@ -117,5 +115,5 @@ class CategoricalColormap(EventedModel):
             ):
                 return False
             return True
-        else:
-            return False
+
+        return False
