@@ -7,7 +7,7 @@ import pytest
 from napari.utils.events import EmitterGroup, EventedList, NestableEventedList
 
 
-@pytest.fixture
+@pytest.fixture()
 def regular_list():
     return list(range(5))
 
@@ -112,7 +112,7 @@ def test_move(test_list):
     test_list.events = Mock(wraps=test_list.events)
 
     def _fail():
-        raise AssertionError("unexpected event called")
+        raise AssertionError('unexpected event called')
 
     test_list.events.removing.connect(_fail)
     test_list.events.removed.connect(_fail)
@@ -162,7 +162,7 @@ OTHER_INDICES = [
 MOVING_INDICES = BASIC_INDICES + OTHER_INDICES
 
 
-@pytest.mark.parametrize('sources,dest,expectation', MOVING_INDICES)
+@pytest.mark.parametrize(('sources', 'dest', 'expectation'), MOVING_INDICES)
 def test_move_multiple(sources, dest, expectation):
     """Test the that we can move objects with the move method"""
     el = EventedList(range(8))
@@ -170,7 +170,7 @@ def test_move_multiple(sources, dest, expectation):
     assert el == [0, 1, 2, 3, 4, 5, 6, 7]
 
     def _fail():
-        raise AssertionError("unexpected event called")
+        raise AssertionError('unexpected event called')
 
     el.events.removing.connect(_fail)
     el.events.removed.connect(_fail)
@@ -219,7 +219,8 @@ def test_move_multiple_mimics_slice_reorder():
 
     # move_multiple also works omitting the insertion index
     el[:] = list(range(8))
-    el.move_multiple(new_order) == [el[i] for i in new_order]
+    el.move_multiple(new_order)
+    assert el == new_order
 
 
 def test_slice(test_list, regular_list):
@@ -255,7 +256,15 @@ def test_nested_indexing():
     # 110 -> '110' -> (1, 1, 0)
     indices = [tuple(int(x) for x in str(n)) for n in flatten(NEST)]
     for index in indices:
-        assert ne_list[index] == int("".join(map(str, index)))
+        assert ne_list[index] == int(''.join(map(str, index)))
+
+    assert ne_list.has_index(1)
+    assert ne_list.has_index((1,))
+    assert ne_list.has_index((1, 2))
+    assert ne_list.has_index((1, 1, 2))
+    assert not ne_list.has_index((1, 1, 3))
+    assert not ne_list.has_index((1, 1, 2, 3, 4))
+    assert not ne_list.has_index(100)
 
 
 # indices in NEST that are themselves lists
@@ -306,9 +315,10 @@ def test_nested_events(meth, group_index):
 
     method_name, args, expected_events = meth
     method = getattr(ne_list[group_index], method_name)
-    if method_name == 'index' and group_index != (1, 1):
-        # the expected value only occurs in index (1, 1)
-        with pytest.raises(ValueError):
+    if method_name == 'index' and group_index == (1, 1, 1):
+        # the expected value of '110' (in the pytest parameters)
+        # is not present in any child of ne_list[1, 1, 1]
+        with pytest.raises(ValueError, match='is not in list'):
             method(*args)
     else:
         # make sure we can call the method without error
@@ -357,7 +367,7 @@ NESTED_NEG_INDICES = [
 NESTED_INDICES = NESTED_POS_INDICES + NESTED_NEG_INDICES  # type: ignore
 
 
-@pytest.mark.parametrize('sources, dest, expectation', NESTED_INDICES)
+@pytest.mark.parametrize(('sources', 'dest', 'expectation'), NESTED_INDICES)
 def test_nested_move_multiple(sources, dest, expectation):
     """Test that moving multiple indices works and emits right events."""
     ne_list = NestableEventedList([0, 1, [20, [210, 211], 22], 3, 4])
@@ -367,7 +377,7 @@ def test_nested_move_multiple(sources, dest, expectation):
 
 
 class E:
-    def __init__(self):
+    def __init__(self) -> None:
         self.events = EmitterGroup(test=None)
 
 
@@ -380,7 +390,7 @@ def test_child_events():
     observed = []
     root.events.connect(lambda e: observed.append(e))
     root.append(e_obj)
-    e_obj.events.test(value="hi")
+    e_obj.events.test(value='hi')
     obs = [(e.type, e.index, getattr(e, 'value', None)) for e in observed]
     expected = [
         ('inserting', 0, None),  # before we inserted b into root
@@ -418,7 +428,7 @@ def test_nested_child_events():
     # and append the event-emitter object to the nested list
     b.append(e_obj)
     # then have the deeply nested event-emitter actually emit an event
-    e_obj.events.test(value="hi")
+    e_obj.events.test(value='hi')
 
     # look at the (type, index, and value) of all of the events emitted by root
     # and make sure they match expectations
