@@ -1,7 +1,8 @@
 import inspect
 import operator
+from collections.abc import Sequence
 from enum import auto
-from typing import ClassVar, List, Protocol, Sequence, Union, runtime_checkable
+from typing import ClassVar, Protocol, Union, runtime_checkable
 from unittest.mock import Mock
 
 import dask.array as da
@@ -9,8 +10,8 @@ import numpy as np
 import pytest
 from dask import delayed
 from dask.delayed import Delayed
-from pydantic import Field
 
+from napari._pydantic_compat import Field, ValidationError
 from napari.utils.events import EmitterGroup, EventedModel
 from napari.utils.events.custom_types import Array
 from napari.utils.misc import StringEnum
@@ -106,7 +107,7 @@ def test_evented_model_with_array():
     )
 
     # try changing shape to something impossible to correctly reshape
-    with pytest.raises(ValueError):
+    with pytest.raises(ValidationError, match='cannot reshape'):
         model.shaped2_values = [1]
 
 
@@ -261,8 +262,7 @@ def test_update_with_inner_model_union():
 def test_update_with_inner_model_protocol():
     @runtime_checkable
     class InnerProtocol(Protocol):
-        def string(self) -> str:
-            ...
+        def string(self) -> str: ...
 
         # Protocol fields are not successfully set without explicit validation.
         @classmethod
@@ -358,7 +358,7 @@ def test_nested_evented_model_serialization():
     class Model(EventedModel):
         nest: NestedModel
 
-    m = Model(nest={'obj': {"a": 1, "b": "hi"}})
+    m = Model(nest={'obj': {'a': 1, 'b': 'hi'}})
     raw = m.json()
     assert raw == r'{"nest": {"obj": {"a": 1, "b": "hi"}}}'
     deserialized = Model.parse_raw(raw)
@@ -439,7 +439,7 @@ class T(EventedModel):
     b: int = 1
 
     @property
-    def c(self) -> List[int]:
+    def c(self) -> list[int]:
         return [self.a, self.b]
 
     @c.setter
@@ -496,7 +496,7 @@ def mocked_object():
 
 
 @pytest.mark.parametrize(
-    'attribute,value,expected_event_values',
+    ('attribute', 'value', 'expected_event_values'),
     [
         ('a', 5, {'a': 5, 'b': None, 'c': [5, 1], 'd': 6, 'e': 50}),
         ('b', 5, {'a': None, 'b': 5, 'c': [1, 5], 'd': 6, 'e': None}),
@@ -550,7 +550,9 @@ def test_evented_model_with_provided_dependencies():
     t.events.b.assert_called_with(value=4)
 
     # should fail if property does not exist
-    with pytest.raises(ValueError):
+    with pytest.raises(
+        ValueError, match='Fields with dependencies must be properties'
+    ):
 
         class T(EventedModel):
             a: int = 1
@@ -563,7 +565,7 @@ def test_evented_model_with_provided_dependencies():
                 dependencies = {'x': ['a']}
 
     # should warn if field does not exist
-    with pytest.warns(match="Unrecognized field dependency"):
+    with pytest.warns(match='Unrecognized field dependency'):
 
         class T(EventedModel):
             a: int = 1
@@ -600,7 +602,7 @@ def test_property_str_annotation():
         a: int = 1
 
         @property
-        def b(self) -> "np.ndarray":  # pragma: no cover
+        def b(self) -> 'np.ndarray':  # pragma: no cover
             return np.ndarray([self.a, self.a])
 
         @property
@@ -624,7 +626,7 @@ def test_events_are_fired_only_if_necessary(monkeypatch):
 
     eq_op_get = Mock(return_value=operator.eq)
     monkeypatch.setattr(
-        "napari.utils.events.evented_model.pick_equality_operator", eq_op_get
+        'napari.utils.events.evented_model.pick_equality_operator', eq_op_get
     )
 
     t = Tt()
@@ -632,8 +634,8 @@ def test_events_are_fired_only_if_necessary(monkeypatch):
     a_eq = Mock(return_value=False)
     b_eq = Mock(return_value=False)
 
-    t.__eq_operators__["a"] = a_eq
-    t.__eq_operators__["b"] = b_eq
+    t.__eq_operators__['a'] = a_eq
+    t.__eq_operators__['b'] = b_eq
 
     t.a = 2
     a_eq.assert_not_called()
@@ -681,3 +683,66 @@ def test_events_are_fired_only_if_necessary(monkeypatch):
     a_eq.assert_called_once()
     b_eq.assert_called_once()
     eq_op_get.assert_called_once_with(9)
+
+
+def _reset_mocks(*args):
+    for el in args:
+        el.reset_mock()
+
+
+def test_single_emit():
+    class SampleClass(EventedModel):
+        a: int = 1
+        b: int = 2
+
+        @property
+        def c(self):
+            return self.a
+
+        @c.setter
+        def c(self, value):
+            self.a = value
+
+        @property
+        def d(self):
+            return self.a + self.b
+
+        @d.setter
+        def d(self, value):
+            self.a = value // 2
+            self.b = value - self.a
+
+        @property
+        def e(self):
+            return self.a - self.b
+
+    s = SampleClass()
+    a_m = Mock()
+    c_m = Mock()
+    d_m = Mock()
+    s.events.a.connect(a_m)
+    s.events.c.connect(c_m)
+    s.events.d.connect(d_m)
+
+    s.a = 4
+    a_m.assert_called_once()
+    c_m.assert_called_once()
+    d_m.assert_called_once()
+
+    _reset_mocks(a_m, c_m, d_m)
+
+    s.c = 6
+    a_m.assert_called_once()
+    c_m.assert_called_once()
+    d_m.assert_called_once()
+
+    _reset_mocks(a_m, c_m, d_m)
+
+    e_m = Mock()
+    s.events.e.connect(e_m)
+
+    s.d = 21
+    a_m.assert_called_once()
+    c_m.assert_called_once()
+    d_m.assert_called_once()
+    e_m.assert_called_once()
