@@ -1,18 +1,17 @@
 import logging
+from collections.abc import Iterable, MutableSequence, Sequence
 from typing import (
     Any,
     Callable,
-    Dict,
-    Iterable,
-    List,
-    MutableSequence,
-    Sequence,
-    Type,
+    Optional,
     TypeVar,
     Union,
     overload,
 )
 
+# change on import from typing when drop python 3.10 support
+from typing_extensions import Self
+
 from napari.utils.translations import trans
 
 logger = logging.getLogger(__name__)
@@ -20,8 +19,8 @@ logger = logging.getLogger(__name__)
 
 Index = Union[int, slice]
 
-_T = TypeVar("_T")
-_L = TypeVar("_L")
+_T = TypeVar('_T')
+_L = TypeVar('_L')
 
 
 class TypedMutableSequence(MutableSequence[_T]):
@@ -48,14 +47,14 @@ class TypedMutableSequence(MutableSequence[_T]):
         self,
         data: Iterable[_T] = (),
         *,
-        basetype: Union[Type[_T], Sequence[Type[_T]]] = (),
-        lookup: Dict[Type[_L], Callable[[_T], Union[_T, _L]]] = None,
+        basetype: Union[type[_T], Sequence[type[_T]]] = (),
+        lookup: Optional[dict[type[_L], Callable[[_T], Union[_T, _L]]]] = None,
     ) -> None:
         if lookup is None:
             lookup = {}
-        self._list: List[_T] = []
-        self._basetypes = (
-            basetype if isinstance(basetype, Sequence) else (basetype,)
+        self._list: list[_T] = []
+        self._basetypes: tuple[type[_T], ...] = (
+            tuple(basetype) if isinstance(basetype, Sequence) else (basetype,)
         )
         self._lookup = lookup.copy()
         self.extend(data)
@@ -66,7 +65,7 @@ class TypedMutableSequence(MutableSequence[_T]):
     def __repr__(self) -> str:
         return repr(self._list)
 
-    def __eq__(self, other: Any):
+    def __eq__(self, other: object) -> bool:
         return self._list == other
 
     def __hash__(self) -> int:
@@ -75,12 +74,12 @@ class TypedMutableSequence(MutableSequence[_T]):
         return id(self)
 
     @overload
-    def __setitem__(self, key: int, value: _T):
-        ...  # pragma: no cover
+    def __setitem__(self, key: int, value: _T): ...  # pragma: no cover
 
     @overload
-    def __setitem__(self, key: slice, value: Iterable[_T]):
-        ...  # pragma: no cover
+    def __setitem__(
+        self, key: slice, value: Iterable[_T]
+    ): ...  # pragma: no cover
 
     def __setitem__(self, key, value):
         if isinstance(key, slice):
@@ -95,10 +94,10 @@ class TypedMutableSequence(MutableSequence[_T]):
         else:
             self._list[key] = self._type_check(value)
 
-    def insert(self, index: int, value: _T):
+    def insert(self, index: int, value: _T) -> None:
         self._list.insert(index, self._type_check(value))
 
-    def __contains__(self, key):
+    def __contains__(self, key: Any) -> bool:
         if type(key) in self._lookup:
             try:
                 self[self.index(key)]
@@ -109,12 +108,15 @@ class TypedMutableSequence(MutableSequence[_T]):
         return super().__contains__(key)
 
     @overload
-    def __getitem__(self, key: int) -> _T:
-        ...  # pragma: no cover
+    def __getitem__(self, key: str) -> _T: ...  # pragma: no cover
 
     @overload
-    def __getitem__(self, key: slice) -> 'TypedMutableSequence[_T]':
-        ...  # pragma: no cover
+    def __getitem__(self, key: int) -> _T: ...  # pragma: no cover
+
+    @overload
+    def __getitem__(
+        self, key: slice
+    ) -> 'TypedMutableSequence[_T]': ...  # pragma: no cover
 
     def __getitem__(self, key):
         """Get an item from the list
@@ -146,7 +148,7 @@ class TypedMutableSequence(MutableSequence[_T]):
         result = self._list[key]
         return self.__newlike__(result) if isinstance(result, list) else result
 
-    def __delitem__(self, key):
+    def __delitem__(self, key) -> None:
         _key = self.index(key) if type(key) in self._lookup else key
         del self._list[_key]
 
@@ -164,7 +166,9 @@ class TypedMutableSequence(MutableSequence[_T]):
             )
         return e
 
-    def __newlike__(self, iterable: Iterable[_T]):
+    def __newlike__(
+        self, iterable: Iterable[_T]
+    ) -> 'TypedMutableSequence[_T]':
         new = self.__class__()
         # seperating this allows subclasses to omit these from their `__init__`
         new._basetypes = self._basetypes
@@ -182,16 +186,18 @@ class TypedMutableSequence(MutableSequence[_T]):
         copy.extend(other)
         return copy
 
-    def __iadd__(self, other: Iterable[_T]) -> 'TypedMutableSequence[_T]':
+    def __iadd__(self, other: Iterable[_T]) -> Self:
         """Add other to self in place (self += other)."""
         self.extend(other)
         return self
 
-    def __radd__(self, other: List) -> List:
+    def __radd__(self, other: list) -> list:
         """Add other to self in place (self += other)."""
         return other + list(self)
 
-    def index(self, value: _L, start: int = 0, stop: int = None) -> int:
+    def index(
+        self, value: _L, start: int = 0, stop: Optional[int] = None
+    ) -> int:
         """Return first index of value.
 
         Parameters
@@ -229,13 +235,15 @@ class TypedMutableSequence(MutableSequence[_T]):
 
         raise ValueError(
             trans._(
-                "{value!r} is not in list",
+                '{value!r} is not in list',
                 deferred=True,
                 value=value,
             )
         )
 
-    def _iter_indices(self, start=0, stop=None):
+    def _iter_indices(
+        self, start: int = 0, stop: Optional[int] = None
+    ) -> Iterable[int]:
         """Iter indices from start to stop.
 
         While this is trivial for this basic sequence type, this method lets
@@ -249,5 +257,5 @@ class TypedMutableSequence(MutableSequence[_T]):
         return None  # type: ignore
 
 
-def _noop(x):
+def _noop(x: _T) -> _T:
     return x
