@@ -1,10 +1,10 @@
-import operator
 import sys
 import warnings
 from contextlib import contextmanager
-from typing import Any, Callable, ClassVar, Dict, Set, Union
+from typing import Any, Callable, ClassVar, Union
 
 import numpy as np
+from app_model.types import KeyBinding
 
 from napari._pydantic_compat import (
     BaseModel,
@@ -20,7 +20,10 @@ from napari.utils.translations import trans
 # encoders for non-napari specific field types.  To declare a custom encoder
 # for a napari type, add a `_json_encode` method to the class itself.
 # it will be added to the model json_encoders in :func:`EventedMetaclass.__new__`
-_BASE_JSON_ENCODERS = {np.ndarray: lambda arr: arr.tolist()}
+_BASE_JSON_ENCODERS = {
+    np.ndarray: lambda arr: arr.tolist(),
+    KeyBinding: lambda v: str(v),
+}
 
 
 @contextmanager
@@ -52,7 +55,7 @@ def no_class_attributes():
     - https://codereview.qt-project.org/c/pyside/pyside-setup/+/261411
     """
 
-    if "PySide2" not in sys.modules:
+    if 'PySide2' not in sys.modules:
         yield
         return
 
@@ -108,14 +111,14 @@ class EventedMetaclass(ModelMetaclass):
                 cls.__properties__[name] = attr
                 # determine compare operator
                 if (
-                    hasattr(attr.fget, "__annotations__")
-                    and "return" in attr.fget.__annotations__
+                    hasattr(attr.fget, '__annotations__')
+                    and 'return' in attr.fget.__annotations__
                     and not isinstance(
-                        attr.fget.__annotations__["return"], str
+                        attr.fget.__annotations__['return'], str
                     )
                 ):
                     cls.__eq_operators__[name] = pick_equality_operator(
-                        attr.fget.__annotations__["return"]
+                        attr.fget.__annotations__['return']
                     )
 
         cls.__field_dependents__ = _get_field_dependents(cls)
@@ -142,7 +145,7 @@ def _update_dependents_from_property_code(
             )
 
 
-def _get_field_dependents(cls: 'EventedModel') -> Dict[str, Set[str]]:
+def _get_field_dependents(cls: 'EventedModel') -> dict[str, set[str]]:
     """Return mapping of field name -> dependent set of property names.
 
     Dependencies will be guessed by inspecting the code of each property
@@ -185,7 +188,7 @@ def _get_field_dependents(cls: 'EventedModel') -> Dict[str, Set[str]]:
     if not cls.__properties__:
         return {}
 
-    deps: Dict[str, Set[str]] = {}
+    deps: dict[str, set[str]] = {}
 
     _deps = getattr(cls.__config__, 'dependencies', None)
     if _deps:
@@ -197,7 +200,7 @@ def _get_field_dependents(cls: 'EventedModel') -> Dict[str, Set[str]]:
                 )
             for field in fields:
                 if field not in cls.__fields__:
-                    warnings.warn(f"Unrecognized field dependency: {field}")
+                    warnings.warn(f'Unrecognized field dependency: {field}')
                 deps.setdefault(field, set()).add(prop_name)
     else:
         # if dependencies haven't been explicitly defined, we can glean
@@ -218,12 +221,15 @@ class EventedModel(BaseModel, metaclass=EventedMetaclass):
     _events: EmitterGroup = PrivateAttr(default_factory=EmitterGroup)
 
     # mapping of name -> property obj for methods that are properties
-    __properties__: ClassVar[Dict[str, property]]
+    __properties__: ClassVar[dict[str, property]]
     # mapping of field name -> dependent set of property names
     # when field is changed, an event for dependent properties will be emitted.
-    __field_dependents__: ClassVar[Dict[str, Set[str]]]
-    __eq_operators__: ClassVar[Dict[str, Callable[[Any, Any], bool]]]
-    __slots__: ClassVar[Set[str]] = {"__weakref__"}  # type: ignore
+    __field_dependents__: ClassVar[dict[str, set[str]]]
+    __eq_operators__: ClassVar[dict[str, Callable[[Any, Any], bool]]]
+    _changes_queue: dict[str, Any] = PrivateAttr(default_factory=dict)
+    _primary_changes: set[str] = PrivateAttr(default_factory=set)
+    _delay_check_semaphore: int = PrivateAttr(0)
+    __slots__: ClassVar[set[str]] = {'__weakref__'}  # type: ignore
 
     # pydantic BaseModel configuration.  see:
     # https://pydantic-docs.helpmanual.io/usage/model_config/
@@ -279,14 +285,73 @@ class EventedModel(BaseModel, metaclass=EventedMetaclass):
         else:
             super().__setattr__(name, value)
 
+    def _check_if_differ(self, name: str, old_value: Any) -> tuple[bool, Any]:
+        """
+        Check new value of a field and emit event if it is different from the old one.
+
+        Returns True if data changed, else False. Return current value.
+        """
+        new_value = getattr(self, name, object())
+        if name in self.__eq_operators__:
+            are_equal = self.__eq_operators__[name]
+        else:
+            are_equal = pick_equality_operator(new_value)
+        return not are_equal(new_value, old_value), new_value
+
     def __setattr__(self, name: str, value: Any) -> None:
+        if name not in getattr(self, 'events', {}):
+            # This is a workaround needed because `EventedConfigFileSettings` uses
+            # `_config_path` before calling the superclass constructor
+            super().__setattr__(name, value)
+            return
+        with ComparisonDelayer(self):
+            self._primary_changes.add(name)
+            self._setattr_impl(name, value)
+
+    def _check_if_values_changed_and_emit_if_needed(self):
+        """
+        Check if field values changed and emit events if needed.
+
+        The advantage of moving this to the end of all the modifications is
+        that comparisons will be performed only once for every potential change.
+        """
+        if self._delay_check_semaphore > 0 or len(self._changes_queue) == 0:
+            # do not run whole machinery if there is no need
+            return
+        to_emit = []
+        for name in self._primary_changes:
+            # primary changes should contains only fields that are changed directly by assigment
+            if name not in self._changes_queue:
+                continue
+            old_value = self._changes_queue[name]
+            if (res := self._check_if_differ(name, old_value))[0]:
+                to_emit.append((name, res[1]))
+            self._changes_queue.pop(name)
+        if not to_emit:
+            # If no direct changes was made then we can skip whole machinery
+            self._changes_queue.clear()
+            self._primary_changes.clear()
+            return
+        for name, old_value in self._changes_queue.items():
+            # check if any of dependent properties changed
+            if (res := self._check_if_differ(name, old_value))[0]:
+                to_emit.append((name, res[1]))
+        self._changes_queue.clear()
+        self._primary_changes.clear()
+
+        with ComparisonDelayer(self):
+            # Again delay comparison to avoid having events caused by callback functions
+            for name, new_value in to_emit:
+                getattr(self.events, name)(value=new_value)
+
+    def _setattr_impl(self, name: str, value: Any) -> None:
         if name not in getattr(self, 'events', {}):
             # fallback to default behavior
             self._super_setattr_(name, value)
             return
 
         # grab current value
-        field_dep = self.__field_dependents__.get(name, {})
+        field_dep = self.__field_dependents__.get(name, set())
         has_callbacks = {
             name: bool(getattr(self.events, name).callbacks)
             for name in field_dep
@@ -306,41 +371,16 @@ class EventedModel(BaseModel, metaclass=EventedMetaclass):
             dep for dep, has_cb in has_callbacks.items() if has_cb
         ]
 
-        before = getattr(self, name, object())
-        before_deps = {}
-        with warnings.catch_warnings():
-            # we still need to check for deprecated properties
-            warnings.simplefilter("ignore", DeprecationWarning)
-            for dep in dep_with_callbacks:
-                before_deps[dep] = getattr(self, dep, object())
+        if name not in self._changes_queue:
+            self._changes_queue[name] = getattr(self, name, object())
+
+        for dep in dep_with_callbacks:
+            if dep not in self._changes_queue:
+                self._changes_queue[dep] = getattr(self, dep, object())
 
         # set value using original setter
         self._super_setattr_(name, value)
 
-        # if different we emit the event with new value
-        after = getattr(self, name)
-        after_deps = {}
-        with warnings.catch_warnings():
-            # we still need to check for deprecated properties
-            warnings.simplefilter("ignore", DeprecationWarning)
-            for dep in dep_with_callbacks:
-                after_deps[dep] = getattr(self, dep, object())
-
-        are_equal = self.__eq_operators__.get(name, operator.eq)
-        if are_equal(after, before):
-            # no change
-            return
-        emitter(value=after)  # emit event
-
-        # emit events for any dependent computed properties as well
-        for dep, value_ in before_deps.items():
-            if dep in self.__eq_operators__:
-                are_equal = self.__eq_operators__[dep]
-            else:
-                are_equal = pick_equality_operator(after_deps[dep])
-            if not are_equal(after_deps[dep], value_):
-                getattr(self.events, dep)(value=after_deps[dep])
-
     # expose the private EmitterGroup publically
     @property
     def events(self) -> EmitterGroup:
@@ -398,7 +438,7 @@ class EventedModel(BaseModel, metaclass=EventedMetaclass):
         if not isinstance(values, dict):
             raise TypeError(
                 trans._(
-                    "Unsupported update from {values}",
+                    'Unsupported update from {values}',
                     deferred=True,
                     values=type(values),
                 )
@@ -466,3 +506,15 @@ def get_defaults(obj: BaseModel):
             d = get_defaults(v.type_)
         dflt[k] = d
     return dflt
+
+
+class ComparisonDelayer:
+    def __init__(self, target: EventedModel):
+        self._target = target
+
+    def __enter__(self):
+        self._target._delay_check_semaphore += 1
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self._target._delay_check_semaphore -= 1
+        self._target._check_if_values_changed_and_emit_if_needed()
