@@ -4,14 +4,17 @@ from io import BytesIO
 from warnings import warn
 
 try:
+    from lxml.etree import ParserError
     from lxml.html import document_fromstring
     from lxml.html.clean import Cleaner
 
     lxml_unavailable = False
-except ModuleNotFoundError:
+except ImportError:
     lxml_unavailable = True
 
-__all__ = ['nbscreenshot']
+from napari.utils.io import imsave_png
+
+__all__ = ['nbscreenshot', 'NotebookScreenshot']
 
 
 class NotebookScreenshot:
@@ -32,17 +35,16 @@ class NotebookScreenshot:
 
     Examples
     --------
-    ```
-    import napari
-    from napari.utils import nbscreenshot
-    from skimage.data import chelsea
 
-    viewer = napari.view_image(chelsea(), name='chelsea-the-cat')
-    nbscreenshot(viewer)
+    >>> import napari
+    >>> from napari.utils import nbscreenshot
+    >>> from skimage.data import chelsea
 
+    >>> viewer = napari.view_image(chelsea(), name='chelsea-the-cat')
+    >>> nbscreenshot(viewer)
     # screenshot just the canvas with the napari viewer framing it
-    nbscreenshot(viewer, canvas_only=False)
-    ```
+    >>> nbscreenshot(viewer, canvas_only=False)
+
     """
 
     def __init__(
@@ -51,7 +53,7 @@ class NotebookScreenshot:
         *,
         canvas_only=False,
         alt_text=None,
-    ):
+    ) -> None:
         """Initialize screenshot object.
 
         Parameters
@@ -77,19 +79,25 @@ class NotebookScreenshot:
         if alt_text is not None:
             if lxml_unavailable:
                 warn(
-                    'The lxml library is not installed, and is required to '
-                    'sanitize alt text for napari screenshots. Alt-text '
-                    'will be stripped altogether without lxml.'
+                    'The lxml_html_clean library is not installed, and is '
+                    'required to sanitize alt text for napari screenshots. '
+                    'Alt Text will be stripped altogether.'
                 )
                 return None
-            alt_text = html.unescape(
-                str(alt_text)
-            )  # cleaner won't recognize unescaped script tags
+            # cleaner won't recognize escaped script tags, so always unescape
+            # to be safe
+            alt_text = html.unescape(str(alt_text))
             cleaner = Cleaner()
-            doc = document_fromstring(alt_text)
-            alt_text = cleaner.clean_html(doc).text_content()
-            # alt_text = html.escape(alt_text)
-            if alt_text == "":
+            try:
+                doc = document_fromstring(alt_text)
+                alt_text = cleaner.clean_html(doc).text_content()
+            except ParserError:
+                warn(
+                    'The provided alt text does not constitute valid html, so it was discarded.',
+                    stacklevel=3,
+                )
+                alt_text = ''
+            if alt_text == '':
                 alt_text = None
         return alt_text
 
@@ -100,16 +108,14 @@ class NotebookScreenshot:
         -------
         In memory binary stream containing PNG screenshot image.
         """
-        from imageio import imsave
-
-        from .._qt.qt_event_loop import get_app
+        from napari._qt.qt_event_loop import get_app
 
         get_app().processEvents()
         self.image = self.viewer.screenshot(
             canvas_only=self.canvas_only, flash=False
         )
         with BytesIO() as file_obj:
-            imsave(file_obj, self.image, format='png')
+            imsave_png(file_obj, self.image)
             file_obj.seek(0)
             png = file_obj.read()
         return png
@@ -117,13 +123,8 @@ class NotebookScreenshot:
     def _repr_html_(self):
         png = self._repr_png_()
         url = 'data:image/png;base64,' + base64.b64encode(png).decode('utf-8')
-        if self.alt_text is None:
-            html_output = f'<img src="{url}"></img>'
-        else:
-            html_output = (
-                f'<img src="{url}" alt="{html.escape(self.alt_text)}"></img>'
-            )
-        return html_output
+        _alt = html.escape(self.alt_text) if self.alt_text is not None else ''
+        return f'<img src="{url}" alt="{_alt}"></img>'
 
 
 nbscreenshot = NotebookScreenshot
